@@ -4,20 +4,16 @@
 class GLWindow
 {
 public:
-	GLWindow(GLWindow *share);
+	GLWindow(GLWindow* Share);
 	virtual ~GLWindow();
 
-	void IncRef()
-	{ m_nRef++; }
-	void DecRef()
-	{ m_nRef--; if (m_nRef == 0) delete this; }
-
-	bool Create(void* data);
+	bool CreateFromWindow(void* Data);
+	bool CreateFromBitmap(void* Data);
 	void DestroyContext();
 
 	bool MakeCurrent();
 	void SwapBuffers();
-	void Redraw();
+	void Redraw(bool ForceRedraw = false);
 	void CaptureMouse();
 	void ReleaseMouse();
 
@@ -35,6 +31,8 @@ public:
 	virtual void OnLeftButtonDown(int x, int y, bool bControl, bool bShift) { };
 	virtual void OnLeftButtonUp(int x, int y, bool bControl, bool bShift) { };
 	virtual void OnLeftButtonDoubleClick(int x, int y, bool bControl, bool bShift) { };
+	virtual void OnMiddleButtonDown(int x, int y, bool bControl, bool bShift) { };
+	virtual void OnMiddleButtonUp(int x, int y, bool bControl, bool bShift) { };
 	virtual void OnRightButtonDown(int x, int y, bool bControl, bool bShift) { };
 	virtual void OnRightButtonUp(int x, int y, bool bControl, bool bShift) { };
 	virtual void OnMouseMove(int x, int y, bool bControl, bool bShift) { };
@@ -46,7 +44,6 @@ protected:
 private:
 	void *m_pData;
 	GLWindow *m_pShare;
-	int m_nRef;
 };
 
 #endif // _GLWINDOW_H_
