@@ -29,8 +29,6 @@ PiecesLibrary::PiecesLibrary()
 	strcpy(m_CategoriesFile, "");
 	m_pMovedReference = NULL;
 	m_nMovedCount = 0;
-	m_pPieceIdx = NULL;
-	m_nPieceCount = 0;
 	m_pTextures = NULL;
 	m_nTextureCount = 0;
 	m_Modified = false;
@@ -44,36 +42,42 @@ PiecesLibrary::~PiecesLibrary()
 
 void PiecesLibrary::Unload ()
 {
+	for (int PieceIdx = 0; PieceIdx < m_Pieces.GetSize(); PieceIdx++)
+		delete m_Pieces[PieceIdx];
+	m_Pieces.RemoveAll();
+
 	strcpy(m_LibraryPath, "");
 
 	free(m_pMovedReference);
 	m_pMovedReference = NULL;
 	m_nMovedCount = 0;
-
-	delete [] m_pPieceIdx;
-	m_pPieceIdx = NULL;
-	m_nPieceCount = 0;
-
 	delete [] m_pTextures;
 	m_pTextures = NULL;
 	m_nTextureCount = 0;
 }
 
+void PiecesLibrary::SetPath(const char* LibPath)
+{
+	strcpy(m_LibraryPath, LibPath);
+
+	// Make sure that the path ends with a '/'
+	int i = strlen(m_LibraryPath)-1;
+	if ((m_LibraryPath[i] != '\\') && (m_LibraryPath[i] != '/'))
+		strcat(m_LibraryPath, "/");
+}
+
 bool PiecesLibrary::Load (const char *libpath)
 {
 	FileDisk idx, bin;
 	char filename[LC_MAXPATH];
 	lcuint16 count, movedcount;
 	lcuint32 binsize;
-	Texture* pTexture;
+//	Texture* pTexture;
 	int i;
 
-	strcpy (m_LibraryPath, libpath);
+	Unload();
 
-	// Make sure that the path ends with a '/'
-	i = strlen(m_LibraryPath)-1;
-	if ((m_LibraryPath[i] != '\\') && (m_LibraryPath[i] != '/'))
-		strcat(m_LibraryPath, "/");
+	SetPath(libpath);
 
 	// Read the piece library index.
 	strcpy (filename, m_LibraryPath);
@@ -103,13 +107,14 @@ bool PiecesLibrary::Load (const char *libpath)
 	idx.ReadShort (&count, 1);
 	idx.Seek (34, SEEK_SET);
 
-	// Load piece indexes
-	delete [] m_pPieceIdx;
-	m_pPieceIdx = new PieceInfo[count];
-	m_nPieceCount = count;
-
-	for (PieceInfo *pElements = m_pPieceIdx; count--; pElements++)
-		pElements->LoadIndex (idx);
+	// Load piece indices
+	m_Pieces.SetSize(count);
+	for (int PieceIdx = 0; PieceIdx < count; PieceIdx++)
+	{
+		PieceInfo* Info = new PieceInfo();
+		Info->LoadIndex(idx);
+		m_Pieces.SetAt(PieceIdx, Info);
+	}
 
 	// Load moved files reference.
 	if (m_pMovedReference != NULL)
@@ -131,7 +136,7 @@ bool PiecesLibrary::Load (const char *libpath)
 	const char* FileName = Sys_ProfileLoadString("Settings", "Categories", "");
 	if (!strlen(FileName) || !LoadCategories(FileName))
 		ResetCategories();
-
+/*
 	// Read the texture index.
 	strcpy(filename, m_LibraryPath);
 	strcat(filename, "textures.idx");
@@ -175,12 +180,14 @@ bool PiecesLibrary::Load (const char *libpath)
 
 	idx.Close();
 	bin.Close();
-
+	*/
 	SystemUpdateCategories(false);
 
 	m_CategoriesModified = false;
 	m_Modified = false;
 
+	Sys_ProfileSaveString("Settings", "PiecesLibrary", m_LibraryPath);
+
 	return true;
 }
 
@@ -208,57 +215,6 @@ bool PiecesLibrary::ValidatePiecesFile(FileDisk& IdxFile, FileDisk& BinFile) con
 		return false;
 	}
 
-	if (version == 3 && PiecesFileVersion == 4)
-	{
-		FileMem NewIdx;
-		char tmp[256];
-
-		version = 4;
-		NewIdx.Write(header, 32);
-		NewIdx.WriteByte(&version, 1);
-		NewIdx.WriteByte(&update, 1);
-
-		IdxFile.Seek(34, SEEK_SET);
-
-		for (int i = 0; i < count; i++)
-		{
-			char name[LC_PIECE_NAME_LEN];
-			memset(name, 0, LC_PIECE_NAME_LEN);
-
-			IdxFile.Read(name, 8);
-			IdxFile.Read(tmp, 64+12+1+4+4+4);
-
-			NewIdx.Write(name, LC_PIECE_NAME_LEN);
-			NewIdx.Write(tmp, 64+12+1+4+4+4);
-		}
-
-		for (int i = 0; i < movedcount * 2; i++)
-		{
-			char name[LC_PIECE_NAME_LEN];
-			memset(name, 0, LC_PIECE_NAME_LEN);
-
-			IdxFile.Read(name, 8);
-			NewIdx.Write(name, LC_PIECE_NAME_LEN);
-		}
-
-		NewIdx.WriteShort(&movedcount, 1);
-		NewIdx.WriteLong(&binsize, 1);
-		NewIdx.WriteShort(&count, 1);
-
-		char FileName[LC_MAXPATH];
-		strcpy(FileName, IdxFile.GetFileName());
-		IdxFile.Close();
-
-		if (!IdxFile.Open(FileName, "wb"))
-			return false;
-
-		IdxFile.Write(NewIdx.GetBuffer(), NewIdx.GetLength());
-		IdxFile.Close();
-
-		IdxFile.Open(FileName, "rb");
-		IdxFile.Seek(IdxPos, SEEK_SET);
-	}
-
 	if (version != PiecesFileVersion)
 	{
 		console.PrintError ("Wrong version of the Pieces Library files.\n");
@@ -331,30 +287,30 @@ bool PiecesLibrary::ValidateTexturesFile (File& IdxFile, File& BinFile) const
 	return true;
 }
 
+PieceInfo* PiecesLibrary::CreatePiecePlaceholder(const char* Name)
+{
+	PieceInfo* Info = new PieceInfo();
+	Info->CreatePlaceholder(Name);
+	m_Pieces.Add(Info);
+	return Info;
+}
+
 // =============================================================================
 // Search functions
 
 // Remember to make 'name' uppercase.
 PieceInfo* PiecesLibrary::FindPieceInfo (const char* name) const
 {
-	PieceInfo* pInfo;
-	int i;
+	for (int PieceIdx = 0; PieceIdx < m_Pieces.GetSize(); PieceIdx++)
+		if (!strcmp(name, m_Pieces[PieceIdx]->m_strName))
+			return m_Pieces[PieceIdx];
 
-	for (i = 0, pInfo = m_pPieceIdx; i < m_nPieceCount; i++, pInfo++)
-		if (!strcmp (name, pInfo->m_strName))
-			return pInfo;
-
-	for (i = 0; i < m_nMovedCount; i++)
+	for (int i = 0; i < m_nMovedCount; i++)
 	{
 		if (!strcmp (&m_pMovedReference[i*LC_PIECE_NAME_LEN*2], name))
 		{
 			char* tmp = &m_pMovedReference[i*LC_PIECE_NAME_LEN*2+LC_PIECE_NAME_LEN];
-
-			for (i = 0, pInfo = m_pPieceIdx; i < m_nPieceCount; i++, pInfo++)
-				if (!strcmp (tmp, pInfo->m_strName))
-					return pInfo;
-
-			break; // something went wrong.
+			return FindPieceInfo(tmp);
 		}
 	}
 
@@ -363,12 +319,15 @@ PieceInfo* PiecesLibrary::FindPieceInfo (const char* name) const
 
 PieceInfo* PiecesLibrary::GetPieceInfo(int index) const
 {
-	return &m_pPieceIdx[index];
+	if (index < 0 || index >= m_Pieces.GetSize())
+		return NULL;
+
+	return m_Pieces[index];
 }
 
 int PiecesLibrary::GetPieceIndex(PieceInfo *pInfo) const
 {
-	return (((char*)pInfo - (char*)m_pPieceIdx) / sizeof (PieceInfo));
+	return m_Pieces.FindIndex(pInfo);
 }
 
 Texture* PiecesLibrary::FindTexture(const char* name) const
@@ -630,9 +589,9 @@ void PiecesLibrary::GetCategoryEntries(int CategoryIndex, bool GroupPieces, PtrA
 	if (m_Categories[CategoryIndex].Name == "Search Results")
 		GroupPieces = false;
 
-	for (int i = 0; i < m_nPieceCount; i++)
+	for (int i = 0; i < m_Pieces.GetSize(); i++)
 	{
-		PieceInfo* Info = &m_pPieceIdx[i];
+		PieceInfo* Info = m_Pieces[i];
 
 		if (!PieceInCategory(Info, m_Categories[CategoryIndex].Keywords))
 			continue;
@@ -693,13 +652,30 @@ void PiecesLibrary::GetPatternedPieces(PieceInfo* Parent, PtrArray<PieceInfo>& P
 
 	Pieces.RemoveAll();
 
-	for (int i = 0; i < m_nPieceCount; i++)
+	for (int i = 0; i < m_Pieces.GetSize(); i++)
 	{
-		PieceInfo* Info = &m_pPieceIdx[i];
+		PieceInfo* Info = m_Pieces[i];
 
 		if (strncmp(Name, Info->m_strName, strlen(Name)) == 0)
 			Pieces.Add(Info);
 	}
+
+	// Sometimes pieces with A and B versions don't follow the same convention (for example, 3040Pxx instead of 3040BPxx).
+	if (Pieces.GetSize() == 0)
+	{
+		strcpy(Name, Parent->m_strName);
+		int Len = strlen(Name);
+		if (Name[Len-1] < '0' || Name[Len-1] > '9')
+			Name[Len-1] = 'P';
+
+		for (int i = 0; i < m_Pieces.GetSize(); i++)
+		{
+			PieceInfo* Info = m_Pieces[i];
+
+			if (strncmp(Name, Info->m_strName, strlen(Name)) == 0)
+				Pieces.Add(Info);
+		}
+	}
 }
 
 void PiecesLibrary::SetCategory(int Index, const String& Name, const String& Keywords)
@@ -736,8 +712,55 @@ void PiecesLibrary::RemoveCategory(int Index)
 // =============================================================================
 // Pieces handling stuff
 
+bool PiecesLibrary::DeleteAllPieces()
+{
+	FileDisk BinFile, IdxFile;
+	char file1[LC_MAXPATH], file2[LC_MAXPATH];
+
+	strcpy(file1, m_LibraryPath);
+	strcat(file1, "pieces-b.old");
+	remove(file1);
+	strcpy(file2, m_LibraryPath);
+	strcat(file2, "pieces.bin");
+	rename(file2, file1);
+
+	if (!BinFile.Open(file2, "wb"))
+		return false;
+
+	BinFile.Write(PiecesBinHeader, 32);
+
+	strcpy(file1, m_LibraryPath);
+	strcat(file1, "pieces-i.old");
+	remove(file1);
+	strcpy(file2, m_LibraryPath);
+	strcat(file2, "pieces.idx");
+	rename(file2, file1);
+
+	if (!IdxFile.Open(file2, "wb"))
+		return false;
+
+	lcuint8 Version = PiecesFileVersion;
+	lcuint8 Update = 0;
+
+	IdxFile.Write(PiecesIdxHeader, 32);
+	IdxFile.WriteByte(&Version, 1);
+	IdxFile.WriteByte(&Update, 1);
+
+	lcuint16 Moved = 0;
+	lcuint32 BinSize = 32;
+	lcuint16 Count = 0;
+
+	IdxFile.WriteShort(&Moved, 1);
+	IdxFile.WriteLong(&BinSize, 1);
+	IdxFile.WriteShort(&Count, 1);
+
+	m_Modified = true;
+
+	return true;
+}
+
 // Remove pieces from the library
-bool PiecesLibrary::DeletePieces (PtrArray<PieceInfo>& Pieces)
+bool PiecesLibrary::DeletePieces(PtrArray<const char>& Pieces)
 {
 	FileDisk newbin, newidx, oldbin, oldidx;
 	char file1[LC_MAXPATH], file2[LC_MAXPATH], tmp[200];
@@ -793,7 +816,7 @@ bool PiecesLibrary::DeletePieces (PtrArray<PieceInfo>& Pieces)
 		oldidx.Read(&name, LC_PIECE_NAME_LEN);
 
 		for (i = 0; i < Pieces.GetSize(); i++)
-			if (strcmp(name, Pieces[i]->m_strName) == 0)
+			if (strcmp(name, Pieces[i]) == 0)
 				break;
 
 		if (i != Pieces.GetSize())
@@ -1400,7 +1423,7 @@ bool PiecesLibrary::ImportTexture (const char* Name)
 // =============================================================================
 // LDraw support
 
-bool PiecesLibrary::ImportLDrawPiece (const char* Filename)
+bool PiecesLibrary::ImportLDrawPiece(const char* Filename, File* NewIdxFile, File* NewBinFile, File* OldIdxFile, File* OldBinFile)
 {
 	LC_LDRAW_PIECE piece;
 
@@ -1408,16 +1431,112 @@ bool PiecesLibrary::ImportLDrawPiece (const char* Filename)
 
 	if (ReadLDrawPiece (Filename, &piece))
 	{
-//		if (FindPieceInfo (piece.name) != NULL)
-//			Sys_MessageBox ("Piece already exists in the library !");
+		char* Moved = strstr(piece.description, "~Moved to ");
+		if (Moved)
+		{
+			lcuint16 Count;
+			OldIdxFile->Seek(-(2+4+2), SEEK_END);
+			OldIdxFile->ReadShort(&Count, 1);
+			lcuint32 cs = Count * 2 * LC_PIECE_NAME_LEN;
+			OldIdxFile->Seek(-(long)(cs+2), SEEK_CUR);
 
-		if (SaveLDrawPiece (&piece))
-			Sys_MessageBox ("Piece successfully imported.");
-		else
+			lcuint32 Length = OldIdxFile->GetPosition();
+			void* Buffer = malloc(Length);
+			OldIdxFile->Seek(0, SEEK_SET);
+			OldIdxFile->Read(Buffer, Length);
+			NewIdxFile->Seek(0, SEEK_SET);
+			NewIdxFile->Write(Buffer, Length);
+			free(Buffer);
+
+			Buffer = malloc(cs);
+			OldIdxFile->Read(Buffer, cs);
+			char* Reference = (char*)Buffer;
+
+			// Add piece to moved list.
+			if (!strchr(Moved, '\\') && !strchr(Moved, '/'))
+			{
+				Moved += strlen("~Moved to ");
+				strupr(Moved);
+
+				char* Dst = NULL;
+				for (int i = 0; i < Count; i++)
+				{
+					if (!strncmp(&Reference[i*2*LC_PIECE_NAME_LEN], piece.name, LC_PIECE_NAME_LEN))
+					{
+						Dst = &Reference[i*LC_PIECE_NAME_LEN+LC_PIECE_NAME_LEN];
+						memset(Dst, 0, LC_PIECE_NAME_LEN);
+						memcpy(Dst, Moved, strlen(Moved));
+					}
+				}
+
+				if (!Dst)
+				{
+					Buffer = realloc(Buffer, 2*LC_PIECE_NAME_LEN*(Count+1));
+					Reference = (char*)Buffer;
+					memset(&Reference[Count*2*LC_PIECE_NAME_LEN], 0, 2*LC_PIECE_NAME_LEN);
+					memcpy(&Reference[Count*2*LC_PIECE_NAME_LEN], piece.name, strlen(piece.name));
+					memcpy(&Reference[Count*2*LC_PIECE_NAME_LEN+LC_PIECE_NAME_LEN], Moved, strlen(Moved));
+					Count++;
+				}
+			}
+
+			NewIdxFile->Write(Reference, Count*2*LC_PIECE_NAME_LEN);
+			NewIdxFile->WriteShort(&Count, 1);
+			free(Buffer);
+
+			Buffer = malloc(4+2);
+			OldIdxFile->Seek(-(4+2), SEEK_END);
+			OldIdxFile->Read(Buffer, 4+2);
+			NewIdxFile->Write(Buffer, 4+2);
+			free(Buffer);
+
+			OldBinFile->Seek(0, SEEK_END);
+			Length = OldBinFile->GetPosition();
+			Buffer = malloc(Length);
+			OldBinFile->Seek(0, SEEK_SET);
+			OldBinFile->Read(Buffer, Length);
+			NewBinFile->Seek(0, SEEK_SET);
+			NewBinFile->Write(Buffer, Length);
+			free(Buffer);
+
+			// Delete existing piece.
+//			lcPtrArray<const char> Pieces;
+//			Pieces.Add(piece.name);
+//			DeletePieces(Pieces);
+		}
+		else if (!SaveLDrawPiece(&piece, NewIdxFile, NewBinFile, OldIdxFile, OldBinFile))
+		{
+			fprintf(stderr, "Error saving library after importing %s.\n", Filename);
 			Sys_MessageBox ("Error saving library.");
+			return false;
+		}
 	}
 	else
+	{
+		void* Buffer;
+		lcuint32 Length;
+
+		OldBinFile->Seek(0, SEEK_END);
+		Length = OldBinFile->GetPosition();
+		Buffer = malloc(Length);
+		OldBinFile->Seek(0, SEEK_SET);
+		OldBinFile->Read(Buffer, Length);
+		NewBinFile->Seek(0, SEEK_SET);
+		NewBinFile->Write(Buffer, Length);
+		free(Buffer);
+
+		OldIdxFile->Seek(0, SEEK_END);
+		Length = OldIdxFile->GetPosition();
+		Buffer = malloc(Length);
+		OldIdxFile->Seek(0, SEEK_SET);
+		OldIdxFile->Read(Buffer, Length);
+		NewIdxFile->Seek(0, SEEK_SET);
+		NewIdxFile->Write(Buffer, Length);
+		free(Buffer);
+
+		fprintf(stderr, "Error reading file %s\n", Filename);
 		Sys_MessageBox ("Error reading file.");
+	}
 
 	FreeLDrawPiece(&piece);
 
@@ -1484,7 +1603,7 @@ static const float ver_flt = 0.3f;
 #define LC_STUD4	5
 
 // stud, technic stud, stud under 1x? plate, stud under ?x? plate
-static const char* valid[12] = { "STUD.DAT", "STUD2.DAT", "STUD3.DAT", "STUD4.DAT" };
+static const char* valid[12] = { "stud.dat", "stud2.dat", "stud3.dat", "stud4.dat" };
 static const unsigned char numvalid = 4;
 
 static int FloatPointsClose(float pt1[], float pt2[])
@@ -1682,7 +1801,7 @@ static connection_t* AddConnection(connection_t* newcon, LC_LDRAW_PIECE* piece)
 static void CreateMesh(group_t* pGroup, lineinfo_t* info, LC_LDRAW_PIECE* piece)
 {
 	lineinfo_t *a, *b;
-	int i, j, k, v;
+	int i, j, k;
 	unsigned int count[256][3], vert = 0;
 	unsigned int quads = 0;
 	unsigned char* bytes;
@@ -1742,12 +1861,9 @@ static void CreateMesh(group_t* pGroup, lineinfo_t* info, LC_LDRAW_PIECE* piece)
 						if ((a->type == j) && (a->color == i))
 						{
 							for (k = 0; k < a->type; k++)
-							for (v = 0; v < (int)piece->verts_count; v++)
-								if (FloatPointsClose(&piece->verts[v*3], &a->points[k*3]))
 								{
-									*drawinfo = v;
+								*drawinfo = a->indices[k];
 									drawinfo++;
-									break;
 								}
 									
 							b->next = a->next;
@@ -1803,13 +1919,10 @@ static void CreateMesh(group_t* pGroup, lineinfo_t* info, LC_LDRAW_PIECE* piece)
 					if ((a->type == j) && (a->color == i))
 					{
 						for (k = 0; k < a->type; k++)
-						for (v = 0; v < (int)piece->verts_count; v++)
-							if (FloatPointsClose(&piece->verts[v*3], &a->points[k*3]))
-							{
-								*drawinfo = v;
-								drawinfo++;
-								break;
-							}
+						{
+							*drawinfo = a->indices[k];
+							drawinfo++;
+						}
 									
 						b->next = a->next;
 						free(a);
@@ -1831,7 +1944,45 @@ static void CreateMesh(group_t* pGroup, lineinfo_t* info, LC_LDRAW_PIECE* piece)
 	bytes[pGroup->infosize-1] = 0; // End
 }
 
-static void decodefile(FILE *F, Matrix *mat, unsigned char defcolor, lineinfo_t* info, char* dir, LC_LDRAW_PIECE* piece)
+// Temp function to convert colors > 255 because the library file format doesn't support them.
+inline int FixupColor(int Color)
+{
+	if (Color < 256)
+		return Color;
+
+	switch (Color)
+	{
+	case 272: return 1; // Dark_Blue -> Blue
+	case 288: return 2; // Dark_Green -> Green
+	case 308: return 6; // Dark_Brown -> Brown
+	case 313: return 11;// Maersk_Blue -> Light_Turquoise
+	case 320: return 4; // Dark_Red -> Red
+	case 335: return 4; // Sand_Red -> Red
+	case 366: return 25; // Earth_Orange -> Orange
+	case 373: return 22; // Sand_Purple -> Purple
+	case 378: return 2; // Sand_Green -> Green
+	case 379: return 1; // Sand_Blue -> Blue
+	case 462: return 25; // Medium_Orange -> Orange
+	case 484: return 25; // Dark_Orange -> Orange
+	case 503: return 7; // Very_Light_Gray -> Light_Gray
+	case 284: return 230; // TLG_Transparent_Reddish_Lilac -> Trans_Pink
+	case 294: return 230; // Glow_In_Dark_Trans -> Trans_Pink
+	case 297: return 14; // Pearl_Gold -> Yellow
+	case 334: return 14; // Chrome_Gold -> Yellow
+	case 383: return 7; // Chrome_Silver -> Light_Gray
+	case 494: return 14; // Electric_Contact_Alloy -> Yellow
+	case 495: return 14; // Electric_Contact_Copper -> Yellow
+	case 256: return 0; // Rubber_Black -> Black
+	case 273: return 1; // Rubber_Blue -> Blue
+	case 324: return 4; // Rubber_Red -> Red
+	case 375: return 7; // Rubber_Light_Gray -> Light_Gray
+	case 511: return 15; // Rubber_White -> White
+	}
+
+	return 0;
+}
+
+static void decodefile(FILE *F, Matrix *mat, int defcolor, lineinfo_t* info, char* dir, LC_LDRAW_PIECE* piece)
 {
 	char buf[1024], fn[LC_MAXPATH], filename[32];
 	unsigned char val;
@@ -1868,7 +2019,7 @@ static void decodefile(FILE *F, Matrix *mat, unsigned char defcolor, lineinfo_t*
 			memset(tex, 0, sizeof(texture_t));
 			f = tex->points;
 
-			sscanf (buf, "%d %d %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %s",
+			sscanf (buf, "%d %i %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %f %s",
 				&type, &color, &f[0], &f[1], &f[2], &f[3], &f[4], &f[5], &f[6], &f[7], &f[8], &f[9],
 				&f[10], &f[11], &f[12], &f[13], &f[14], &f[15], &f[16], &f[17], &f[18], &f[19], tex->name);
 			tex->color = color;
@@ -1890,22 +2041,28 @@ static void decodefile(FILE *F, Matrix *mat, unsigned char defcolor, lineinfo_t*
 		{
 		case 1:
 		{
-			sscanf (buf, "%d %d %f %f %f %f %f %f %f %f %f %f %f %f %s",
+			sscanf (buf, "%d %i %f %f %f %f %f %f %f %f %f %f %f %f %s",
 				&type, &color, &fm[0], &fm[1], &fm[2], &fm[3], &fm[4], &fm[5], &fm[6], &fm[7], &fm[8], &fm[9], &fm[10], &fm[11], filename);
 
-			strcpy (fn, dir);
-			strcat (fn, "p/");
-			strcat (fn, filename);
+			strlwr(filename);
+
+			for (unsigned int i = 0; i < strlen(filename); i++)
+				if (filename[i] == '\\')
+					filename[i] = '/';
 
-			strupr(filename);
 			for (val = 0; val < numvalid; val++)
 				if (strcmp(filename, valid[val]) == 0)
 					break;
+
 			if (val != numvalid)
 				break;
 
 			if (color == 16) color = defcolor;
 
+			strcpy(fn, dir);
+			strcat(fn, "p/");
+			strcat(fn, filename);
+
 			tf = fopen (fn, "rt");
 
 			if (!tf)
@@ -1930,20 +2087,23 @@ static void decodefile(FILE *F, Matrix *mat, unsigned char defcolor, lineinfo_t*
 				m1.FromLDraw(fm);
 				m2.Multiply(*mat, m1);
 
-				decodefile(tf, &m2, (unsigned char)color, info, dir, piece);
+				decodefile(tf, &m2, color, info, dir, piece);
 				while (info->next)
 					info = info->next;
 				fclose(tf);
 			}
+			else
+				printf("Could not find file \"%s\".\n", filename);
+
 		} break;
 
 		case 2:
 		{
-			sscanf (buf, "%d %d %f %f %f %f %f %f", &type, &color, 
+			sscanf (buf, "%d %i %f %f %f %f %f %f", &type, &color, 
 				&info->points[0], &info->points[1], &info->points[2],
 				&info->points[3], &info->points[4], &info->points[5]);
 			if (color == 16) color = defcolor;
-			if (color > 256) color -= 256;
+			color = FixupColor(color); // TODO: handle colors in hex format, some parts are using it (3070bp09, 3626bpao, 3626bpb5, 3960ps3)
 			info->color = color;
 			ConvertPoints(info->points, 2);
 			mat->TransformPoints(info->points, 2);
@@ -1951,12 +2111,12 @@ static void decodefile(FILE *F, Matrix *mat, unsigned char defcolor, lineinfo_t*
 
 		case 3:
 		{
-			sscanf (buf, "%d %d %f %f %f %f %f %f %f %f %f", &type, &color, 
+			sscanf (buf, "%d %i %f %f %f %f %f %f %f %f %f", &type, &color, 
 				&info->points[0], &info->points[1], &info->points[2],
 				&info->points[3], &info->points[4], &info->points[5],
 				&info->points[6], &info->points[7], &info->points[8]);
 			if (color == 16) color = defcolor;
-			if (color > 256) color -= 256;
+			color = FixupColor(color);
 			info->color = color;
 			ConvertPoints(info->points, 3);
 			mat->TransformPoints(info->points, 3);
@@ -1964,13 +2124,13 @@ static void decodefile(FILE *F, Matrix *mat, unsigned char defcolor, lineinfo_t*
 
 		case 4:
 		{
-			sscanf (buf, "%d %d %f %f %f %f %f %f %f %f %f %f %f %f", &type, &color, 
+			sscanf (buf, "%d %i %f %f %f %f %f %f %f %f %f %f %f %f", &type, &color, 
 				&info->points[0], &info->points[1], &info->points[2],
 				&info->points[3], &info->points[4], &info->points[5],
 				&info->points[6], &info->points[7], &info->points[8],
 				&info->points[9], &info->points[10], &info->points[11]);
 			if (color == 16) color = defcolor;
-			if (color > 256) color -= 256;
+			color = FixupColor(color);
 			info->color = color;
 			ConvertPoints(info->points, 4);
 			mat->TransformPoints(info->points, 4);
@@ -2026,16 +2186,14 @@ static void decodeconnections(FILE *F, Matrix *mat, unsigned char defcolor, char
 			continue;
 		}
 
-		sscanf (buf, "%d %d %f %f %f %f %f %f %f %f %f %f %f %f %s",
+		sscanf (buf, "%d %i %f %f %f %f %f %f %f %f %f %f %f %f %s",
 			&type, &color, &fm[0], &fm[1], &fm[2], &fm[3], &fm[4], &fm[5], &fm[6], &fm[7], &fm[8], &fm[9], &fm[10], &fm[11], filename);
 
-		strcpy (fn, dir);
-		strcat (fn, "P/");
-		strcat (fn, filename);
+		strlwr(filename);
 
 		if (color == 16) color = defcolor;
+		color = FixupColor(color);
 
-		strupr(filename);
 		for (val = 0; val < numvalid; val++)
 		if (strcmp(filename, valid[val]) == 0)
 		{
@@ -2213,7 +2371,15 @@ static void decodeconnections(FILE *F, Matrix *mat, unsigned char defcolor, char
 			continue;
 		}
 
-		tf = fopen (fn, "rt");
+		for (unsigned int i = 0; i < strlen(filename); i++)
+			if (filename[i] == '\\')
+				filename[i] = '/';
+					
+		strcpy(fn, dir);
+		strcat(fn, "p/");
+		strcat(fn, filename);
+
+		tf = fopen(fn, "rt");
 
 		if (!tf)
 		{
@@ -2243,6 +2409,10 @@ static void decodeconnections(FILE *F, Matrix *mat, unsigned char defcolor, char
 //				info = info->next;
 			fclose(tf);
 		}
+		else
+		{
+			printf("Could not find file \"%s\".\n", filename);
+		}
 
 		memset (buf, 0, sizeof(buf));
 	}
@@ -2323,8 +2493,11 @@ bool ReadLDrawPiece(const char* filename, LC_LDRAW_PIECE* piece)
 				if ((unique % 500) == 0)
 					verts = (float*)realloc(verts, sizeof(float)*3*(unique+500));
 				memcpy(&verts[unique*3], &lf->points[j*3], sizeof(float)*3);
+				i = unique;
 				unique++;
 			}
+
+			lf->indices[j] = i;
 		}
 	}
 
@@ -2355,64 +2528,46 @@ bool ReadLDrawPiece(const char* filename, LC_LDRAW_PIECE* piece)
 	return true;
 }
 
-bool SaveLDrawPiece(LC_LDRAW_PIECE* piece)
+bool SaveLDrawPiece(LC_LDRAW_PIECE* piece, File* NewIdxFile, File* NewBinFile, File* OldIdxFile, File* OldBinFile)
 {
-	FileDisk newbin, newidx, oldbin, oldidx;
-	char file1[LC_MAXPATH], file2[LC_MAXPATH];
-	unsigned short count, moved;
-	unsigned long i, j, cs, binoff = 0, delta;
+	lcuint16 count, moved;
+	lcuint32 i, j, cs, binoff = 0, delta;
 	void* membuf;
-	short scale, sb[6];
-	PiecesLibrary *pLib = lcGetPiecesLibrary();
+	lcuint16 scale, sb[6];
 
-	strcpy(file1, pLib->GetLibraryPath());
-	strcat(file1, "pieces-b.old");
-	remove(file1);
-	strcpy(file2, pLib->GetLibraryPath());
-	strcat(file2, "pieces.bin");
-	rename(file2, file1);
+	File& NewIdx = *NewIdxFile;
+	File& NewBin = *NewBinFile;
+	File& OldIdx = *OldIdxFile;
+	File& OldBin = *OldBinFile;
 
-	if ((!oldbin.Open(file1, "rb")) ||
-		(!newbin.Open(file2, "wb")))
-		return false;
+	OldIdx.Seek(0, SEEK_SET);
+	OldBin.Seek(0, SEEK_SET);
 
-	strcpy(file1, pLib->GetLibraryPath());
-	strcat(file1, "pieces-i.old");
-	remove(file1);
-	strcpy(file2, pLib->GetLibraryPath());
-	strcat(file2, "pieces.idx");
-	rename(file2, file1);
-
-	if ((!oldidx.Open(file1, "rb")) ||
-		(!newidx.Open(file2, "wb")))
-		return false;
-
-
-	oldidx.Seek(-2, SEEK_END);
-	oldidx.ReadShort(&count, 1);
-	oldidx.Seek(34, SEEK_SET);
+	OldIdx.Seek(-2, SEEK_END);
+	OldIdx.ReadShort(&count, 1);
+	OldIdx.Seek(34, SEEK_SET);
 
 	for (j = 0; j < count; j++)
 	{
 		char name[LC_PIECE_NAME_LEN];
-		oldidx.Read(name, LC_PIECE_NAME_LEN);
+		OldIdx.Read(name, LC_PIECE_NAME_LEN);
 
 		if (strcmp(name, piece->name) == 0)
 		{
-			oldidx.Seek(64+12+1+4, SEEK_CUR);
-			oldidx.ReadLong(&binoff, 1);
-			oldidx.ReadLong(&delta, 1);
-			oldidx.Seek(-(LC_PIECE_NAME_LEN+64+12+1+4+4+4), SEEK_CUR);
+			OldIdx.Seek(64+12+1+4, SEEK_CUR);
+			OldIdx.ReadLong(&binoff, 1);
+			OldIdx.ReadLong(&delta, 1);
+			OldIdx.Seek(-(LC_PIECE_NAME_LEN+64+12+1+4+4+4), SEEK_CUR);
 			delta += binoff;
 			break;
 		}
-		oldidx.Seek(64+12+1+4+4+4, SEEK_CUR);
+		OldIdx.Seek(64+12+1+4+4+4, SEEK_CUR);
 	}
 
 	if (binoff == 0)
-		binoff = oldbin.GetLength();
+		binoff = OldBin.GetLength();
 
-	cs = oldidx.GetPosition();
+	cs = OldIdx.GetPosition();
 	membuf = malloc(cs);
 	if (membuf == NULL)
 	{
@@ -2420,9 +2575,9 @@ bool SaveLDrawPiece(LC_LDRAW_PIECE* piece)
 		return false;
 	}
 
-	oldidx.Seek(0, SEEK_SET);
-	oldidx.Read(membuf, cs);
-	newidx.Write(membuf, cs);
+	OldIdx.Seek(0, SEEK_SET);
+	OldIdx.Read(membuf, cs);
+	NewIdx.Write(membuf, cs);
 	free(membuf);
 
 	membuf = malloc (binoff);
@@ -2432,9 +2587,9 @@ bool SaveLDrawPiece(LC_LDRAW_PIECE* piece)
 		return false;
 	}
 
-	oldbin.Seek(0, SEEK_SET);
-	oldbin.Read(membuf, binoff);
-	newbin.Write(membuf, binoff);
+	OldBin.Seek(0, SEEK_SET);
+	OldBin.Read(membuf, binoff);
+	NewBin.Write(membuf, binoff);
 	free(membuf);
 
 	// Save piece
@@ -2553,68 +2708,68 @@ bool SaveLDrawPiece(LC_LDRAW_PIECE* piece)
 		scale = 100;
 
 	// Write the vertex data
-	newbin.WriteLong(&piece->verts_count, 1);
+	NewBin.WriteLong(&piece->verts_count, 1);
 	for (i = 0; i < piece->verts_count; i++)
 	{
 		float tmp[3] = { scale*piece->verts[(i*3)], scale*piece->verts[(i*3)+1], scale*piece->verts[(i*3)+2] };
 		short sh[3] = { (short)tmp[0], (short)tmp[1], (short)tmp[2] };
-		newbin.WriteShort(&sh, 3);
+		NewBin.WriteShort(&sh, 3);
 	}
 
 	// Write the connections information
 	for (s = 0, con = piece->connections; con; con = con->next)
 		s++;
-	newbin.WriteShort(&s, 1);
+	NewBin.WriteShort(&s, 1);
 
 	for (con = piece->connections; con; con = con->next)
 	{
 		float tmp[3] = { scale*con->pos[0], scale*con->pos[1], scale*con->pos[2] };
 		short sh[3] = { (short)tmp[0], (short)tmp[1], (short)tmp[2] };
 
-		newbin.WriteByte(&con->type, 1);
-		newbin.WriteShort(sh, 3);
+		NewBin.WriteByte(&con->type, 1);
+		NewBin.WriteShort(sh, 3);
 
 		sh[0] = (short)(con->up[0]*(1<<14));
 		sh[1] = (short)(con->up[1]*(1<<14));
 		sh[2] = (short)(con->up[2]*(1<<14));
-		newbin.WriteShort(sh, 3);
+		NewBin.WriteShort(sh, 3);
 	}
 
 	// Textures
 	for (bt = 0, tex = piece->textures; tex; tex = tex->next)
 		bt++;
-	newbin.WriteByte(&bt, 1);
+	NewBin.WriteByte(&bt, 1);
 
 	for (tex = piece->textures; tex; tex = tex->next)
 	{
-		newbin.WriteByte(&tex->color, 1);
-		newbin.Write(tex->name, 8);
+		NewBin.WriteByte(&tex->color, 1);
+		NewBin.Write(tex->name, 8);
 
 		for (i = 0; i < 12; i++)
 		{
 			float tmp[1] = { tex->points[i]*scale };
 			short sh[1] = { (short)tmp[0] };
-			newbin.WriteShort(sh, 1);
+			NewBin.WriteShort(sh, 1);
 		}
 
 		for (i = 12; i < 20; i++)
 		{
 			float tmp = tex->points[i];
 			short sh[1] = { (short)tmp };
-			newbin.WriteShort(sh, 1);
+			NewBin.WriteShort(sh, 1);
 		}
 	}
 
 	for (s = 0, group = piece->groups; group; group = group->next)
 		s++;
-	newbin.WriteShort(&s, 1);
+	NewBin.WriteShort(&s, 1);
 
 	for (group = piece->groups; group; group = group->next)
 	{
 		for (bt = 0; bt < 5; bt++)
 			if (!group->connections[bt])
 				break;
-		newbin.WriteByte(&bt, 1);
+		NewBin.WriteByte(&bt, 1);
 
 		for (bt = 0; bt < 5; bt++)
 		{
@@ -2624,15 +2779,15 @@ bool SaveLDrawPiece(LC_LDRAW_PIECE* piece)
 			for (s = 0, con = piece->connections; con; con = con->next, s++)
 				if (con == group->connections[bt])
 					break;
-			newbin.WriteShort(&s, 1);
+			NewBin.WriteShort(&s, 1);
 		}
 // TODO: make this endian-safe
-		newbin.Write(group->drawinfo, group->infosize);
+		NewBin.Write(group->drawinfo, group->infosize);
 	}
 
 	// Now write the index
-	newidx.Write(piece->name, LC_PIECE_NAME_LEN);
-	newidx.Write(piece->description, 64);
+	NewIdx.Write(piece->name, LC_PIECE_NAME_LEN);
+	NewIdx.Write(piece->description, 64);
 
 	for (i = 0; i < 6; i++)
 	{
@@ -2642,7 +2797,7 @@ bool SaveLDrawPiece(LC_LDRAW_PIECE* piece)
 //		sb[i] = scale*box[i];
 		sb[i] = (short)ff;
 	}
-	newidx.WriteShort(sb, 6);
+	NewIdx.WriteShort(sb, 6);
 
 	// Calculate flags.
 	bt = LC_PIECE_COUNT;
@@ -2653,63 +2808,58 @@ bool SaveLDrawPiece(LC_LDRAW_PIECE* piece)
 		bt |= LC_PIECE_MEDIUM;
 
 	if (piece->long_info)
-		bt |= LC_PIECE_LONGDATA;
+		bt |= LC_PIECE_LONGDATA_FILE;
 
-	newidx.WriteByte(&bt, 1);
+	NewIdx.WriteByte(&bt, 1);
 
 	i = 0;//PiecesLibrary::GetDefaultPieceGroup(piece->description);
-	newidx.WriteLong(&i, 1);
-	newidx.WriteLong(&binoff, 1);
+	NewIdx.WriteLong(&i, 1);
+	NewIdx.WriteLong(&binoff, 1);
 
-	i = newbin.GetLength() - binoff;
-	newidx.WriteLong(&i, 1);
+	i = NewBin.GetLength() - binoff;
+	NewIdx.WriteLong(&i, 1);
 
 	// replacing a piece
 	if (j != count)
 	{
-		unsigned long d = newbin.GetPosition() - delta;
-		oldidx.Seek (LC_PIECE_NAME_LEN+64+12+1+4+4+4, SEEK_CUR);
+		unsigned long d = NewBin.GetPosition() - delta;
+		OldIdx.Seek (LC_PIECE_NAME_LEN+64+12+1+4+4+4, SEEK_CUR);
 		for (j++; j < count; j++)
 		{
-			unsigned long dw;
+			lcuint32 dw;
 			char buf[LC_PIECE_NAME_LEN+64+12+1+4];
-			oldidx.Read(buf, LC_PIECE_NAME_LEN+64+12+1+4);
-			oldidx.ReadLong(&dw, 1);
+			OldIdx.Read(buf, LC_PIECE_NAME_LEN+64+12+1+4);
+			OldIdx.ReadLong(&dw, 1);
 			dw += d;
-			newidx.Write(buf, LC_PIECE_NAME_LEN+64+12+1+4);
-			newidx.WriteLong(&dw, 1);
-			oldidx.ReadLong(&dw, 1);
-			newidx.WriteLong(&dw, 1);
+			NewIdx.Write(buf, LC_PIECE_NAME_LEN+64+12+1+4);
+			NewIdx.WriteLong(&dw, 1);
+			OldIdx.ReadLong(&dw, 1);
+			NewIdx.WriteLong(&dw, 1);
 		}
 
-		d = oldbin.GetLength()-delta;
+		d = OldBin.GetLength()-delta;
 		membuf = malloc (d);
-		oldbin.Seek (delta, SEEK_SET);
-		oldbin.Read (membuf, d);
-		newbin.Write(membuf, d);
+		OldBin.Seek(delta, SEEK_SET);
+		OldBin.Read(membuf, d);
+		NewBin.Write(membuf, d);
 		free(membuf);
 	}
 	else
 		count++;
 
 	// Fix the end of the index
-	oldidx.Seek(-(2+4+2), SEEK_END);
-	oldidx.ReadShort(&moved, 1);
-	cs = 2+(moved*16);
-	oldidx.Seek(-(long)cs, SEEK_CUR);
+	OldIdx.Seek(-(2+4+2), SEEK_END);
+	OldIdx.ReadShort(&moved, 1);
+	cs = 2+(moved*LC_PIECE_NAME_LEN*2);
+	OldIdx.Seek(-(long)cs, SEEK_CUR);
 	membuf = malloc(cs);
-	oldidx.Read(membuf, cs);
-	newidx.Write(membuf, cs);
+	OldIdx.Read(membuf, cs);
+	NewIdx.Write(membuf, cs);
 	free(membuf);
 
-	binoff = newbin.GetPosition();
-	newidx.WriteLong(&binoff, 1);
-	newidx.WriteShort(&count, 1);
-
-	oldidx.Close();
-	oldbin.Close();
-	newidx.Close();
-	newbin.Close();
+	binoff = NewBin.GetPosition();
+	NewIdx.WriteLong(&binoff, 1);
+	NewIdx.WriteShort(&count, 1);
 
 	return true;
 }
