@@ -479,7 +479,7 @@ void Piece::MinIntersectDist(LC_CLICKLINE* pLine)
 
 	float* verts = m_pPieceInfo->m_fVertexArray;
 
-	if (m_pPieceInfo->m_nFlags & LC_PIECE_LONGDATA)
+	if (m_pPieceInfo->m_nFlags & LC_PIECE_LONGDATA_INDICES)
 	{
 		lcuint32* info = (lcuint32*)m_pDrawInfo, colors, i;
 		colors = *info;
@@ -698,7 +698,7 @@ bool Piece::IntersectsVolume(const Vector4* Planes, int NumPlanes)
 	float* verts = m_pPieceInfo->m_fVertexArray;
 	bool ret = false;
 
-	if (m_pPieceInfo->m_nFlags & LC_PIECE_LONGDATA)
+	if (m_pPieceInfo->m_nFlags & LC_PIECE_LONGDATA_INDICES)
 	{
 		lcuint32* info = (lcuint32*)m_pDrawInfo, colors, i;
 		colors = *info;
@@ -904,7 +904,7 @@ void Piece::BuildDrawInfo()
 
 		if (add)
 		{
-			if (m_pPieceInfo->m_nFlags & LC_PIECE_LONGDATA)
+			if (m_pPieceInfo->m_nFlags & LC_PIECE_LONGDATA_INDICES)
 			{
 				lcuint32* p, curcol, colors;
 				p = (lcuint32*)dg->drawinfo;
@@ -956,7 +956,7 @@ void Piece::BuildDrawInfo()
 	vert += (colcount*4)+1;
 
 	// Build the info
-	if (m_pPieceInfo->m_nFlags & LC_PIECE_LONGDATA)
+	if (m_pPieceInfo->m_nFlags & LC_PIECE_LONGDATA_INDICES)
 	{
 		m_pDrawInfo = malloc(vert*sizeof(lcuint32));
 		lcuint32* drawinfo = (lcuint32*)m_pDrawInfo;
@@ -1193,7 +1193,7 @@ void Piece::Render(bool bLighting, bool bEdges, unsigned char* nLastColor, bool*
 		glDisable(GL_TEXTURE_2D);
 	}
 
-	if (m_pPieceInfo->m_nFlags & LC_PIECE_LONGDATA)
+	if (m_pPieceInfo->m_nFlags & LC_PIECE_LONGDATA_INDICES)
 	{
 		lcuint32 colors, *info = (lcuint32*)m_pDrawInfo;
 		colors = *info;
@@ -1834,50 +1834,3 @@ void Piece::RemoveConnections(CONNECTION_TYPE* pConnections)
 	for (i = 0; i < RebuildList.GetSize(); i++)
 		RebuildList[i]->BuildDrawInfo();
 }
-
-/*
-// Performs exact collision detection using the RAPID library.
-// Check if there are 2 objects at the same place at the same time
-BOOL CPiece::Collide(CPiece* pPiece)
-{
-	return CollideAt(pPiece, m_fRotation, m_fPosition);
-}
-
-// Use this to check if the piece can be modified
-BOOL CPiece::CollideAt(CPiece* pPiece, float rot[4], float pos[3])
-{
-	double rotation1[3][3], rotation2[3][3];
-	double translation1[3], translation2[3];
-
-	CMatrix m1(rot, pos);
-	rotation1[0][0] = m1.m[0];
-	rotation1[0][1] = m1.m[4];
-	rotation1[0][2] = m1.m[8];
-	rotation1[1][0] = m1.m[1];
-	rotation1[1][1] = m1.m[5];
-	rotation1[1][2] = m1.m[9];
-	rotation1[2][0] = m1.m[2];
-	rotation1[2][1] = m1.m[6];
-	rotation1[2][2] = m1.m[10];
-	translation1[0] = m1.m[12];
-	translation1[1] = m1.m[13];
-	translation1[2] = m1.m[14];
-
-	CMatrix m2(pPiece->m_fRotation, pPiece->m_fPosition);
-	rotation2[0][0] = m2.m[0];
-	rotation2[0][1] = m2.m[4];
-	rotation2[0][2] = m2.m[8];
-	rotation2[1][0] = m2.m[1];
-	rotation2[1][1] = m2.m[5];
-	rotation2[1][2] = m2.m[9];
-	rotation2[2][0] = m2.m[2];
-	rotation2[2][1] = m2.m[6];
-	rotation2[2][2] = m2.m[10];
-	translation2[0] = m2.m[12];
-	translation2[1] = m2.m[13];
-	translation2[2] = m2.m[14];
-
-	return CollisionCheck(rotation1, translation1, m_pInfo->m_pRModel,
-		rotation2, translation2, pPiece->m_pInfo->m_pRModel);
-}
-*/
