@@ -23,6 +23,7 @@
 #include "lc_application.h"
 #include "library.h"
 #include "preview.h"
+#include "camera.h"
 
 View* view;
 
@@ -52,7 +53,6 @@ static gint main_quit (GtkWidget *widget, GdkEvent* event, gpointer data);
 // =============================================================================
 // Static functions
 
-// try to find the path of the executable
 static void init_paths (char *argv0)
 {
   char temppath[PATH_MAX];
@@ -74,9 +74,6 @@ static void init_paths (char *argv0)
     endpwent();
   }
 
-  if (home == NULL)
-    home = ".";
-
   strcpy (temppath, argv0);
   if (!strrchr(temppath, '/'))
   {
@@ -96,8 +93,11 @@ static void init_paths (char *argv0)
 
       if (*path == '~')
       {
+				if (home)
 	strcpy(temppath, home);
-	++path;
+				else
+					strcpy(temppath, ".");
+				path++;
       }
 
       if (last > (path+1))
@@ -109,7 +109,7 @@ static void init_paths (char *argv0)
       strcat (temppath, argv0);
 
       if (access(temppath, X_OK) == 0 )
-	++found;
+				found++;
       path = last+1;
 
     } while (*last && !found);
@@ -156,12 +156,6 @@ void OnCommand(GtkWidget* widget, gpointer data)
     return;
   }
 
-  if (id >= ID_VIEW_VIEWPORTS_01 && id <= ID_VIEW_VIEWPORTS_14)
-  {
-    project->HandleCommand(LC_VIEW_VIEWPORTS, id - ID_VIEW_VIEWPORTS_01);
-    return;
-  }
-
   if (id >= ID_CAMERA_FIRST && id <= ID_CAMERA_LAST)
   {
     project->HandleCommand(LC_VIEW_CAMERA_MENU, id - ID_CAMERA_FIRST);
@@ -180,6 +174,61 @@ void OnCommand(GtkWidget* widget, gpointer data)
       project->HandleCommand(LC_TOOLBAR_SNAPMENU, 5);
     } break;
 
+    case ID_SNAP_X:
+    {
+      project->HandleCommand(LC_TOOLBAR_SNAPMENU, 0);
+    } break;
+
+    case ID_SNAP_Y:
+    {
+      project->HandleCommand(LC_TOOLBAR_SNAPMENU, 1);
+    } break;
+
+    case ID_SNAP_Z:
+    {
+      project->HandleCommand(LC_TOOLBAR_SNAPMENU, 2);
+    } break;
+
+    case ID_SNAP_ALL:
+    {
+      project->HandleCommand(LC_TOOLBAR_SNAPMENU, 3);
+    } break;
+
+    case ID_SNAP_NONE:
+    {
+      project->HandleCommand(LC_TOOLBAR_SNAPMENU, 4);
+    } break;
+
+    case ID_SNAP_ON:
+    {
+      project->HandleCommand(LC_TOOLBAR_SNAPMENU, 6);
+    } break;
+
+    case ID_LOCK_X:
+    {
+      project->HandleCommand(LC_TOOLBAR_LOCKMENU, 0);
+    } break;
+
+    case ID_LOCK_Y:
+    {
+      project->HandleCommand(LC_TOOLBAR_LOCKMENU, 1);
+    } break;
+
+    case ID_LOCK_Z:
+    {
+      project->HandleCommand(LC_TOOLBAR_LOCKMENU, 2);
+    } break;
+
+    case ID_LOCK_NONE:
+    {
+      project->HandleCommand(LC_TOOLBAR_LOCKMENU, 3);
+    } break;
+
+    case ID_LOCK_ON:
+    {
+      project->HandleCommand(LC_TOOLBAR_LOCKMENU, 4);
+    } break;
+
     case ID_VIEW_CREATE:
     {
       GtkWidget *wnd, *w, *frame;
@@ -195,7 +244,7 @@ void OnCommand(GtkWidget* widget, gpointer data)
       gtk_frame_set_shadow_type (GTK_FRAME (frame), GTK_SHADOW_IN);               
 
       View *v = new View (project, view);
-      v->Create (&w);
+      v->CreateFromWindow (&w);
 
       gtk_container_add (GTK_CONTAINER (frame), w);
       gtk_widget_show (w);
@@ -328,6 +377,16 @@ static gint key_press_event(GtkWidget* widget, GdkEventKey* event, gpointer data
     }
   }
 
+  if ((code >= '0') && (code <= '9') && ((event->state & GDK_CONTROL_MASK) == 0))
+  {
+    if (event->state & GDK_SHIFT_MASK)
+      lcGetActiveProject()->HandleCommand((LC_COMMANDS)(LC_EDIT_MOVEZ_SNAP_0 + code - '0'), 0);
+    else
+      lcGetActiveProject()->HandleCommand((LC_COMMANDS)(LC_EDIT_MOVEXY_SNAP_0 + code - '0'), 0);
+
+    return TRUE;
+  }
+
   if (code != 0)
   {
     if (lcGetActiveProject()->OnKeyDown(code, (event->state & GDK_CONTROL_MASK) != 0, 
@@ -422,7 +481,7 @@ static void update_window_layout ()
   // first thing we need to create the widgets
   if (drawing_area == NULL)
   {
-    view->Create (&drawing_area);
+    view->CreateFromWindow (&drawing_area);
 
     gtk_widget_set_events (GTK_WIDGET (drawing_area), GDK_EXPOSURE_MASK | GDK_KEY_PRESS_MASK |
 			   GDK_BUTTON_PRESS_MASK | GDK_BUTTON_RELEASE_MASK | GDK_POINTER_MOTION_MASK |
@@ -534,6 +593,7 @@ int main (int argc, char* argv[])
   }
 
   view = new View (lcGetActiveProject(), NULL);
+  view->m_Camera = lcGetActiveProject()->GetCamera(LC_CAMERA_MAIN);
 
   //  main_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title (GTK_WINDOW (((GtkWidget*)(*main_window))), "LeoCAD");
@@ -659,13 +719,14 @@ int main (int argc, char* argv[])
 
 #include "pixmaps/icon32.xpm"
 
+	lcGetActiveProject()->UpdateInterface();
   main_window->UpdateMRU ();
 
   GdkPixmap *gdkpixmap;
   GdkBitmap *mask;
 
   gdkpixmap = gdk_pixmap_create_from_xpm_d (((GtkWidget*)(*main_window))->window, &mask,
-                 &((GtkWidget*)(*main_window))->style->bg[GTK_STATE_NORMAL], icon32);
+                                           &((GtkWidget*)(*main_window))->style->bg[GTK_STATE_NORMAL], (gchar**)icon32);
   gdk_window_set_icon (((GtkWidget*)(*main_window))->window, NULL, gdkpixmap, mask);
 
   gtk_widget_show (GTK_WIDGET (((GtkWidget*)(*main_window))));
