@@ -6,6 +6,8 @@
 #include <gtk/gtk.h>
 #include <X11/keysym.h>
 #include <sys/time.h>
+#include <sys/types.h>
+#include <dirent.h>
 #include "opengl.h"
 #include "gtkmisc.h"
 #include "camera.h"
@@ -15,6 +17,7 @@
 #include "toolbar.h"
 #include "dialogs.h"
 #include "globals.h"
+#include "lc_application.h"
 
 // =============================================================================
 // Cursor functions
@@ -85,27 +88,77 @@ void Sys_FinishMemoryRender(void* param)
 // Misc stuff
 
 // FIXME: should have a table of LC_KEY_* defined
-bool Sys_KeyDown (int key)
+bool Sys_KeyDown(int Key)
 {
-  char keys[32];
-  int x;
+	char keys[32];
+	int x;
 
-  XQueryKeymap (GDK_DISPLAY (), keys);
+	XQueryKeymap(GDK_DISPLAY(), keys);
 
-  x = XKeysymToKeycode (GDK_DISPLAY (), XK_Control_L);
-  if (keys[x/8] & (1 << (x % 8)))
-    return true;
+	if (Key == KEY_CONTROL)
+	{
+		x = XKeysymToKeycode(GDK_DISPLAY(), XK_Control_L);
+		if (keys[x/8] & (1 << (x % 8)))
+			return true;
 
-  x = XKeysymToKeycode (GDK_DISPLAY (), XK_Control_R);
-  if (keys[x/8] & (1 << (x % 8)))
-    return true;
+		x = XKeysymToKeycode(GDK_DISPLAY(), XK_Control_R);
+		if (keys[x/8] & (1 << (x % 8)))
+			return true;
+	}
+	else if (Key == KEY_ALT)
+	{
+		x = XKeysymToKeycode(GDK_DISPLAY(), XK_Alt_L);
+		if (keys[x/8] & (1 << (x % 8)))
+			return true;
 
-  return false;
+		x = XKeysymToKeycode(GDK_DISPLAY(), XK_Alt_R);
+		if (keys[x/8] & (1 << (x % 8)))
+			return true;
+	}
+
+	return false;
 }
 
+void Sys_GetFileList(const char* Path, ObjArray<String>& FileList)
+{
+	struct dirent* Entry;
+	char DirPath[LC_MAXPATH], FilePath[LC_MAXPATH];
 
+	strcpy(DirPath, Path);
+	int Length = strlen(DirPath);
+	if (DirPath[Length - 1] != '/')
+		strcat(DirPath, "/");
 
+	FileList.RemoveAll();
 
+	DIR* Dir = opendir(DirPath);
+	if (!Dir)
+	{
+		printf("Couldn't open directory.\n");
+		return;
+	}
+
+	while ((Entry = readdir(Dir)))
+	{
+		int Length;
+
+		if (Entry->d_type != DT_REG)
+			continue;
+
+		Length = strlen(Entry->d_name);
+
+		if (Length < 5)
+			continue;
+
+		if (strcmp(Entry->d_name + Length - 4, ".dat"))
+			continue;
+
+		sprintf(FilePath, "%s%s", DirPath, Entry->d_name);
+		FileList.Add(FilePath);
+	}
+
+	closedir(Dir);
+}
 
 // String
 char* strupr(char* string)
@@ -161,25 +214,11 @@ long SystemGetTicks()
 }
 
 // User Interface
-void SystemUpdateViewport(int new_vp, int old_vp)
-{
-  char buf[64];
-  sprintf (buf, "menu_view_viewports_%02d", new_vp+1);
-  gpointer item = gtk_object_get_data (GTK_OBJECT (((GtkWidget*)(*main_window))), buf);
-
-  if (!item)
-    return;
-
-  ignore_commands = true;
-  gtk_check_menu_item_set_state (GTK_CHECK_MENU_ITEM (item), TRUE);  
-  ignore_commands = false;
-}
-
 void SystemUpdateCategories(bool SearchOnly)
 {
 }
 
-static void create_bitmap_and_mask_from_xpm (GdkBitmap **bitmap, GdkBitmap **mask, gchar **xpm)
+static void create_bitmap_and_mask_from_xpm (GdkBitmap **bitmap, GdkBitmap **mask, const char **xpm)
 {
   int height, width, colors;
   char pixmap_buffer [(32 * 32)/8];
@@ -240,7 +279,7 @@ void SystemUpdateAction(int new_action, int old_action)
     return;
 
   GtkWidget* button;
-  char** xpm = NULL;
+  const char** xpm = NULL;
   int x, y;
 
   switch (new_action)
@@ -290,17 +329,20 @@ void SystemUpdateAction(int new_action, int old_action)
   GdkColor white = {0, 0xffff, 0xffff, 0xffff};
   GdkColor black = {0, 0x0000, 0x0000, 0x0000};
 
-  if (xpm != NULL)
+  if (GDK_IS_WINDOW(drawing_area))
   {
-    create_bitmap_and_mask_from_xpm (&bitmap, &mask, xpm);
-    cursor = gdk_cursor_new_from_pixmap (bitmap, mask, &white, &black, x, y);
-    gdk_window_set_cursor (drawing_area->window, cursor);
-  }
-  else
-  {
-    cursor = gdk_cursor_new (GDK_LEFT_PTR);
-    gdk_window_set_cursor (drawing_area->window, cursor);
-    gdk_cursor_destroy (cursor);
+    if (xpm != NULL)
+    {
+      create_bitmap_and_mask_from_xpm (&bitmap, &mask, xpm);
+      cursor = gdk_cursor_new_from_pixmap (bitmap, mask, &white, &black, x, y);
+      gdk_window_set_cursor (drawing_area->window, cursor);
+    }
+    else
+    {
+      cursor = gdk_cursor_new (GDK_LEFT_PTR);
+      gdk_window_set_cursor (drawing_area->window, cursor);
+      gdk_cursor_destroy (cursor);
+    }
   }
 
   ignore_commands = true;
@@ -313,13 +355,13 @@ void SystemUpdateColorList(int new_color)
   colorlist_set(new_color);
 }
 
-void SystemUpdateRenderingMode(bool bBackground, bool bFast)
+void SystemUpdateRenderingMode(bool bFast)
 {
   if (!main_toolbar.fast)
     return;
 
   ignore_commands = true;
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(main_toolbar.fast), bFast);
+  gtk_toggle_tool_button_set_active(GTK_TOGGLE_TOOL_BUTTON(main_toolbar.fast), bFast);
   ignore_commands = false;
 }
 
@@ -356,10 +398,28 @@ void SystemUpdateSnap(const unsigned long snap)
     return;
 
   ignore_commands = true;
-  gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON(main_toolbar.angle), (snap & LC_DRAW_SNAP_A) != 0);
+  gtk_toggle_tool_button_set_active(GTK_TOGGLE_TOOL_BUTTON(main_toolbar.angle), (snap & LC_DRAW_SNAP_A) != 0);
   ignore_commands = false;
 
-  // TODO: popup menu
+  void* item;
+
+  ignore_commands = true;
+
+  item = gtk_object_get_data(GTK_OBJECT(main_toolbar.snap_menu), "snap_x");
+  gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), (snap & LC_DRAW_SNAP_X) ? TRUE : FALSE);
+  item = gtk_object_get_data(GTK_OBJECT(main_toolbar.snap_menu), "snap_y");
+  gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), (snap & LC_DRAW_SNAP_Y) ? TRUE : FALSE);
+  item = gtk_object_get_data(GTK_OBJECT(main_toolbar.snap_menu), "snap_z");
+  gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), (snap & LC_DRAW_SNAP_Z) ? TRUE : FALSE);
+
+  item = gtk_object_get_data(GTK_OBJECT(main_toolbar.lock_menu), "lock_x");
+  gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), (snap & LC_DRAW_LOCK_X) ? TRUE : FALSE);
+  item = gtk_object_get_data(GTK_OBJECT(main_toolbar.lock_menu), "lock_y");
+  gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), (snap & LC_DRAW_LOCK_Y) ? TRUE : FALSE);
+  item = gtk_object_get_data(GTK_OBJECT(main_toolbar.lock_menu), "lock_z");
+  gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(item), (snap & LC_DRAW_LOCK_Z) ? TRUE : FALSE);
+
+  ignore_commands = false;
 }
 
 void SystemUpdateCurrentCamera(Camera* pOld, Camera* pNew, Camera* pCamera)
@@ -487,16 +547,16 @@ void SystemUpdateAnimation(bool bAnimation, bool bAddKeys)
 
 void SystemUpdateSnap(unsigned short move_snap, unsigned short RotateSnap)
 {
-  if (!label_snap)
-    return;
+	if (!label_snap)
+		return;
 
-  char text[11];
-  if (move_snap)
-    sprintf (text, "Move x%i", move_snap);
-  else
-    strcpy (text, "Move /2");
+	char Text[256], xy[32], z[32];
 
-  gtk_label_set (GTK_LABEL (label_snap), text);
+	lcGetActiveProject()->GetSnapDistanceText(xy, z);
+
+	sprintf(Text, " M: %s %s R: %d ", xy, z, RotateSnap);
+
+	gtk_label_set (GTK_LABEL (label_snap), Text);
 }
 
 void SystemUpdateSelected(unsigned long flags, int SelectedCount, Object* Focus)
@@ -511,7 +571,7 @@ void SystemUpdateSelected(unsigned long flags, int SelectedCount, Object* Focus)
 
   gtk_widget_set_sensitive (item, (flags & LC_SEL_UNSELECTED) != 0);
   item = GTK_WIDGET (gtk_object_get_data (GTK_OBJECT (((GtkWidget*)(*main_window))), "menu_edit_select_none"));
-  gtk_widget_set_sensitive (item, flags & (LC_SEL_PIECE|LC_SEL_CAMERA|LC_SEL_LIGHT) != 0);
+  gtk_widget_set_sensitive (item, (flags & (LC_SEL_PIECE|LC_SEL_CAMERA|LC_SEL_LIGHT)) != 0);
   item = GTK_WIDGET (gtk_object_get_data (GTK_OBJECT (((GtkWidget*)(*main_window))), "menu_edit_select_invert"));
   gtk_widget_set_sensitive (item, (flags & LC_SEL_NO_PIECES) == 0);
   item = GTK_WIDGET (gtk_object_get_data (GTK_OBJECT (((GtkWidget*)(*main_window))), "menu_edit_select_byname"));
@@ -609,7 +669,7 @@ void SystemFinish()
 }
 
 // FIXME: remove 
-int SystemDoMessageBox(char* prompt, int mode)
+int SystemDoMessageBox(const char* prompt, int mode)
 {
   return msgbox_execute (prompt, "LeoCAD", mode);
 }
@@ -618,71 +678,59 @@ bool SystemDoDialog(int mode, void* param)
 {
   switch (mode)
   {
-    case LC_DLG_FILE_OPEN_PROJECT: {
+    case LC_DLG_FILE_OPEN_PROJECT:
       return openprojectdlg_execute ((char*)param) == LC_OK;
-    } break;
 
-    case LC_DLG_FILE_SAVE_PROJECT: {
+    case LC_DLG_FILE_SAVE_PROJECT:
       return saveprojectdlg_execute ((char*)param) == LC_OK;
-    } break;
 
-    case LC_DLG_FILE_MERGE_PROJECT: {
+    case LC_DLG_FILE_MERGE_PROJECT:
       return openprojectdlg_execute ((char*)param) == LC_OK;
-    } break;
 
-    case LC_DLG_ABOUT: {
+    case LC_DLG_FILE_OPEN:
+      return openprojectdlg_execute ((char*)param) == LC_OK;
+
+    case LC_DLG_ABOUT:
       return aboutdlg_execute(param) == LC_OK;
-    } break;
 
-    case LC_DLG_ARRAY: {
+    case LC_DLG_ARRAY:
       return arraydlg_execute(param) == LC_OK;
-    } break;
 
-    case LC_DLG_HTML: {
+    case LC_DLG_HTML:
       return htmldlg_execute(param) == LC_OK;
-    } break;
 
-    case LC_DLG_POVRAY: {
+    case LC_DLG_POVRAY:
       return povraydlg_execute(param) == LC_OK;
-    } break;
 
-    case LC_DLG_WAVEFRONT: {
-      return filedlg_execute("Save File", (char*)param) == LC_OK;
-    } break;
+    case LC_DLG_WAVEFRONT:
+      return wavefrontdlg_execute(param) == LC_OK;
 
-    case LC_DLG_PREFERENCES: {
+    case LC_DLG_PREFERENCES:
       return preferencesdlg_execute(param) == LC_OK;
-    } break;
 
-    case LC_DLG_PICTURE_SAVE: {
+    case LC_DLG_PICTURE_SAVE:
       return savepicturedlg_execute (param) == LC_OK;
-    } break;
 
-    case LC_DLG_MINIFIG: {
+    case LC_DLG_MINIFIG:
       return minifigdlg_execute(param) == LC_OK;
-    } break;
 
-    case LC_DLG_PROPERTIES: {
+    case LC_DLG_PROPERTIES:
       return propertiesdlg_execute(param) == LC_OK;
-    } break;
 
-    case LC_DLG_LIBRARY: {
+    case LC_DLG_LIBRARY:
       return librarydlg_execute(param) == LC_OK;
-    } break;
 
-    case LC_DLG_SELECTBYNAME: {
-    } break;
+    case LC_DLG_SELECTBYNAME:
+      break;
 
-    case LC_DLG_STEPCHOOSE: {
-    } break;
+    case LC_DLG_STEPCHOOSE:
+      break;
 
-    case LC_DLG_EDITGROUPS: {
+    case LC_DLG_EDITGROUPS:
       return groupeditdlg_execute(param) == LC_OK;
-    } break;
 
-    case LC_DLG_GROUP: {
+    case LC_DLG_GROUP:
       return groupdlg_execute(param) == LC_OK;
-    } break;
   }
 
   return false;
@@ -694,16 +742,21 @@ void SystemDoPopupMenu(int nMenu, int x, int y)
 
 void SystemDoWaitCursor(int code)
 {
+  GdkWindow* window = ((GtkWidget*)(*main_window))->window;
+
+  if (!GDK_IS_WINDOW(window))
+    return;
+
   if (code == 1)
   {
     GdkCursor *cursor = gdk_cursor_new (GDK_WATCH);
-    gdk_window_set_cursor (((GtkWidget*)(*main_window))->window, cursor);
+    gdk_window_set_cursor(window, cursor);
     gdk_cursor_destroy (cursor);
   } 
   else
   {
     GdkCursor *cursor = gdk_cursor_new (GDK_LEFT_PTR);
-    gdk_window_set_cursor (((GtkWidget*)(*main_window))->window, cursor);
+    gdk_window_set_cursor(window, cursor);
     gdk_cursor_destroy (cursor);
   }
 }
