@@ -3,12 +3,11 @@
 
 #include "stdafx.h"
 #include "LeoCAD.h"
+#include <WindowsX.h>
 
 #include "CADDoc.h"
 #include "CADView.h"
-#include "WheelWnd.h"
 #include "Tools.h"
-#include "PrevView.h"
 #include "project.h"
 #include "globals.h"
 #include "system.h"
@@ -49,7 +48,6 @@ BEGIN_MESSAGE_MAP(CCADView, CView)
 	ON_COMMAND(ID_FILE_PRINT_DIRECT, CView::OnFilePrint)
 	ON_NOTIFY(TBN_DROPDOWN, AFX_IDW_TOOLBAR, OnDropDown)
 	ON_MESSAGE(WM_LC_SET_STEP, OnSetStep)
-	ON_MESSAGE(WM_LC_WHEEL_PAN, OnAutoPan)
 	ON_MESSAGE(WM_LC_SET_CURSOR, OnChangeCursor)
 END_MESSAGE_MAP()
 
@@ -58,15 +56,12 @@ END_MESSAGE_MAP()
 
 CCADView::CCADView()
 {
-	m_pPixels = NULL;
 	m_hCursor = NULL;
-  m_pView = NULL;
+	m_pView = NULL;
 }
 
 CCADView::~CCADView()
 {
-	if (m_pPixels)
-		free (m_pPixels);
 }
 
 BOOL CCADView::PreCreateWindow(CREATESTRUCT& cs)
@@ -123,32 +118,9 @@ void CCADView::OnDraw(CDC* /*pDC*/)
 // Derived to use our version of the toolbar
 void CCADView::OnFilePrintPreview() 
 {
-	// In derived classes, implement special window handling here
-	// Be sure to Unhook Frame Window close if hooked.
-
-	// must not create this on the frame.  Must outlive this function
-	CPrintPreviewState* pState = new CPrintPreviewState;
-	pState->lpfnCloseProc = _AfxPreviewCloseProcEx;
-
-	// DoPrintPreview's return value does not necessarily indicate that
-	// Print preview succeeded or failed, but rather what actions are necessary
-	// at this point.  If DoPrintPreview returns TRUE, it means that
-	// OnEndPrintPreview will be (or has already been) called and the
-	// pState structure will be/has been deleted.
-	// If DoPrintPreview returns FALSE, it means that OnEndPrintPreview
-	// WILL NOT be called and that cleanup, including deleting pState
-	// must be done here.
-
-	if (!DoPrintPreview(IDR_PREVIEW, this,
-			RUNTIME_CLASS(CCADPreviewView), pState))
-	{
-		// In derived classes, reverse special window handling here for
-		// Preview failure case
-
-		TRACE0("Error: DoPrintPreview failed.\n");
-		AfxMessageBox(AFX_IDP_COMMAND_FAILURE);
-		delete pState;      // preview failed to initialize, delete State now
-	}
+#ifndef SHARED_HANDLERS
+	AFXPrintPreview(this);
+#endif
 }
 
 BOOL CCADView::OnPreparePrinting(CPrintInfo* pInfo)
@@ -168,7 +140,7 @@ BOOL CCADView::OnPreparePrinting(CPrintInfo* pInfo)
 
 	if (pInfo->m_bPreview)
 	{
-		CFrameWnd* pFrame = (CFrameWnd*)AfxGetMainWnd();
+		CFrameWndEx* pFrame = (CFrameWndEx*)AfxGetMainWnd();
 
 		POSITION pos = pFrame->m_listControlBars.GetHeadPosition();
 		while (pos != NULL)
@@ -232,15 +204,8 @@ void CCADView::OnPrint(CDC* pDC, CPrintInfo* pInfo)
 
 	int tw = pw, th = ph; // tile size
 
-	MEMORYSTATUS MemStat;
-	MemStat.dwLength = sizeof(MEMORYSTATUS);
-	GlobalMemoryStatus(&MemStat);
-
-	if (DWORD(pw*ph*3) > MemStat.dwTotalPhys)
-	{
-		tw = 512;
-		th = 512;
-	}
+	if (tw > 1024 || th > 1024)
+		tw = th = 1024;
 
 	HDC hMemDC = CreateCompatibleDC(GetDC()->m_hDC);
 	LPBITMAPINFOHEADER lpbi;
@@ -258,23 +223,16 @@ void CCADView::OnPrint(CDC* pDC, CPrintInfo* pInfo)
 	bi.bmiHeader.biXPelsPerMeter = 2925;
 	bi.bmiHeader.biYPelsPerMeter = 2925;
 	
-  HBITMAP hBm = CreateDIBSection(hMemDC, &bi, DIB_RGB_COLORS, (void **)&lpbi, NULL, (DWORD)0);
+	HBITMAP hBm = CreateDIBSection(hMemDC, &bi, DIB_RGB_COLORS, (void **)&lpbi, NULL, (DWORD)0);
 	HBITMAP hBmOld = (HBITMAP)SelectObject(hMemDC, hBm);
 
-    // Setting up a Pixel format for the DIB surface
-	PIXELFORMATDESCRIPTOR pfd = { sizeof(PIXELFORMATDESCRIPTOR),
-			1,PFD_DRAW_TO_BITMAP | PFD_SUPPORT_OPENGL | PFD_SUPPORT_GDI,
-			PFD_TYPE_RGBA, 24, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 16,
-			0, 0, PFD_MAIN_PLANE, 0, 0, 0, 0 };
-	int pixelformat = OpenGLChoosePixelFormat(hMemDC, &pfd);
-	OpenGLDescribePixelFormat (hMemDC, pixelformat, sizeof(PIXELFORMATDESCRIPTOR), &pfd);
-	OpenGLSetPixelFormat (hMemDC, pixelformat, &pfd);
-	
-	// Creating OpenGL context
-  HGLRC hmemrc = pfnwglCreateContext(hMemDC);
-	pfnwglMakeCurrent(hMemDC, hmemrc);
-//	if (!pfnwglShareLists(m_hglRC, hmemrc))
-//		pDoc->RebuildDisplayLists(TRUE);
+	View view(project, project->m_ActiveView);
+	view.m_Camera = project->m_ActiveView->m_Camera;
+	view.CreateFromBitmap(hMemDC);
+	view.MakeCurrent();
+	view.OnSize(tw, th);
+	project->AddView(&view);
+
 	project->RenderInitialize();
 
 	LOGFONT lf;
@@ -295,11 +253,6 @@ void CCADView::OnPrint(CDC* pDC, CPrintInfo* pInfo)
 	unsigned short nOldTime = project->m_bAnimation ? project->m_nCurFrame : project->m_nCurStep;
 	UINT nRenderTime = 1+((pInfo->m_nCurPage-1)*rows*cols);
 
-	int oldSizex = project->m_nViewX;
-	int oldSizey = project->m_nViewY;
-	project->m_nViewX = tw;
-	project->m_nViewY = th;
-
 	for (int r = 0; r < rows; r++)
 	for (int c = 0; c < cols; c++)
 	{
@@ -322,7 +275,7 @@ void CCADView::OnPrint(CDC* pDC, CPrintInfo* pInfo)
 			pCam->StartTiledRendering(tw, th, pw, ph, viewaspect);
 			do 
 			{
-				project->Render(true);
+				project->Render(&view, true);
 				glFinish();
 				int tr, tc, ctw, cth;
 				pCam->GetTileInfo(&tr, &tc, &ctw, &cth);
@@ -341,7 +294,7 @@ void CCADView::OnPrint(CDC* pDC, CPrintInfo* pInfo)
 		}
 		else
 		{
-			project->Render(true);
+			project->Render(&view, true);
 			glFinish();
 			lpbi = (LPBITMAPINFOHEADER)GlobalLock(MakeDib(hBm, 24));
 			
@@ -354,11 +307,6 @@ void CCADView::OnPrint(CDC* pDC, CPrintInfo* pInfo)
 			if (lpbi) GlobalFreePtr(lpbi);
 		}
 
-		// OpenGL Rendering
-//			CCamera* pOld = pDoc->GetActiveCamera();
-//			pDoc->m_ViewCameras[pDoc->m_nActiveViewport] = pDoc->GetCamera(CAMERA_MAIN);
-//			pDoc->m_ViewCameras[pDoc->m_nActiveViewport] = pOld;
-
 		DWORD dwPrint = theApp.GetProfileInt("Settings","Print", PRINT_NUMBERS|PRINT_BORDER);
 		if (dwPrint & PRINT_NUMBERS)
 		{
@@ -398,11 +346,8 @@ void CCADView::OnPrint(CDC* pDC, CPrintInfo* pInfo)
 		project->m_nCurFrame = nOldTime;
 	else
 		project->m_nCurStep = (unsigned char)nOldTime;
-	project->m_nViewX = oldSizex;
-	project->m_nViewY = oldSizey;
 
-	pfnwglMakeCurrent(NULL, NULL);
-	pfnwglDeleteContext(hmemrc);
+	view.DestroyContext();
 	SelectObject(hMemDC, hBmOld);
 	DeleteObject(hBm);
 	DeleteDC(hMemDC);
@@ -411,7 +356,6 @@ void CCADView::OnPrint(CDC* pDC, CPrintInfo* pInfo)
 	SelectObject(pDC->m_hDC, OldFont);
 	DeleteObject(font);
 	glFinish();
-//		pfnwglMakeCurrent(m_pDC->m_hDC, m_hglRC);
 
 	lf.lfHeight = -MulDiv(12, pDC->GetDeviceCaps(LOGPIXELSY), 72);
 	lf.lfWeight = FW_REGULAR;
@@ -537,181 +481,6 @@ void CCADView::OnEndPrinting(CDC* /*pDC*/, CPrintInfo* /*pInfo*/)
 //	pfnwglMakeCurrent(m_pDC->GetSafeHdc(), m_hglRC);
 }
 
-void CCADView::OnEndPrintPreview(CDC* pDC, CPrintInfo* pInfo, POINT point, CCADPreviewView* pView) 
-{
-//	CView::OnEndPrintPreview(CDC* pDC, CPrintInfo* pInfo, POINT, CPreviewView* pView)
-	ASSERT_VALID(pDC);
-	ASSERT_VALID(pView);
-
-	if (pView->m_pPrintView != NULL)
-		pView->m_pPrintView->OnEndPrinting(pDC, pInfo);
-
-	CFrameWnd* pParent;
-	CWnd* pNaturalParent = pView->GetParentFrame();
-	pParent = DYNAMIC_DOWNCAST(CFrameWnd, pNaturalParent);
-	if (pParent == NULL || pParent->IsIconic())
-		pParent = (CFrameWnd*)AfxGetThread()->m_pMainWnd;
-
-	ASSERT_VALID(pParent);
-	ASSERT_KINDOF(CFrameWnd, pParent);
-
-	// restore the old main window
-	pParent->OnSetPreviewMode(FALSE, pView->m_pPreviewState);
-
-	// Force active view back to old one
-	pParent->SetActiveView(pView->m_pPreviewState->pViewActiveOld);
-	if (pParent != GetParentFrame())
-		OnActivateView(TRUE, this, this);   // re-activate view in real frame
-	pView->DestroyWindow();     // destroy preview view
-			// C++ object will be deleted in PostNcDestroy
-
-	// restore main frame layout and idle message
-	pParent->RecalcLayout();
-	pParent->SendMessage(WM_SETMESSAGESTRING, (WPARAM)AFX_IDS_IDLEMESSAGE, 0L);
-	pParent->UpdateWindow();
-///
-
-
-	pfnwglMakeCurrent(NULL, NULL);
-/*
-	if (OpenGLGetPixelFormat(m_pDC->GetSafeHdc()) == 0)
-	{
-		delete m_pDC;
-		m_pDC = new CClientDC(this);
-
-		PIXELFORMATDESCRIPTOR pfd = { sizeof(PIXELFORMATDESCRIPTOR), 1,
-			PFD_DRAW_TO_WINDOW | PFD_SUPPORT_OPENGL | PFD_DOUBLEBUFFER,
-			PFD_TYPE_RGBA, 24, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 32,
- 			0, 0, PFD_MAIN_PLANE, 0, 0, 0, 0 };
-	
-		int pixelformat = OpenGLChoosePixelFormat(m_pDC->GetSafeHdc(), &pfd);
-		if (pixelformat == 0)
-		{
-			AfxMessageBox("ChoosePixelFormat failed");
-		}
-
-		if (OpenGLSetPixelFormat(m_pDC->m_hDC, pixelformat, &pfd) == FALSE)
-		{
-			AfxMessageBox("SetPixelFormat failed");
-		}
-	}
-
-	if (pfnwglMakeCurrent(m_pDC->m_hDC, m_hglRC) == FALSE)
-	{
-		LPTSTR lpMsgBuf;
-		FormatMessage(FORMAT_MESSAGE_ALLOCATE_BUFFER | FORMAT_MESSAGE_FROM_SYSTEM,
-		    NULL, GetLastError(), MAKELANGID(LANG_NEUTRAL, SUBLANG_DEFAULT), // Default language
-			(LPTSTR) &lpMsgBuf, 0, NULL);
-
-		::MessageBox(NULL, lpMsgBuf, "Error", MB_OK|MB_ICONINFORMATION);
-		LocalFree(lpMsgBuf);	
-	}
-*/
-	InvalidateRect(NULL, FALSE);
-}
-
-BOOL CCADView::DoPrintPreview(UINT nIDResource, CView* pPrintView, CRuntimeClass* pPreviewViewClass, CPrintPreviewState* pState)
-{
-	ASSERT_VALID_IDR(nIDResource);
-	ASSERT_VALID(pPrintView);
-	ASSERT(pPreviewViewClass != NULL);
-	ASSERT(pPreviewViewClass->IsDerivedFrom(RUNTIME_CLASS(CCADPreviewView)));
-	ASSERT(pState != NULL);
-
-	CFrameWnd* pParent;
-	CWnd* pNaturalParent = pPrintView->GetParentFrame();
-	pParent = DYNAMIC_DOWNCAST(CFrameWnd, pNaturalParent);
-	if (pParent == NULL || pParent->IsIconic())
-		pParent = (CFrameWnd*)AfxGetThread()->m_pMainWnd;
-
-	ASSERT_VALID(pParent);
-	ASSERT_KINDOF(CFrameWnd, pParent);
-
-	CCreateContext context;
-	context.m_pCurrentFrame = pParent;
-	context.m_pCurrentDoc = GetDocument();
-	context.m_pLastView = this;
-
-	// Create the preview view object
-	CCADPreviewView* pView = (CCADPreviewView*)pPreviewViewClass->CreateObject();
-	if (pView == NULL)
-	{
-		TRACE0("Error: Failed to create preview view.\n");
-		return FALSE;
-	}
-	ASSERT_KINDOF(CCADPreviewView, pView);
-	pView->m_pPreviewState = pState;        // save pointer
-
-	pParent->OnSetPreviewMode(TRUE, pState);    // Take over Frame Window
-
-	// Create the toolbar from the dialog resource
-	pView->m_pToolBar = new CFlatToolBar;
-
-	if (!pView->m_pToolBar->Create(pParent, WS_CHILD | WS_VISIBLE | CBRS_TOP, AFX_IDW_PREVIEW_BAR) ||
-		!pView->m_pToolBar->LoadToolBar(nIDResource))
-	{
-		TRACE0("Error: Preview could not create toolbar.\n");
-		pParent->OnSetPreviewMode(FALSE, pState);   // restore Frame Window
-		delete pView->m_pToolBar;       // not autodestruct yet
-		pView->m_pToolBar = NULL;
-		pView->m_pPreviewState = NULL;  // do not delete state structure
-		delete pView;
-		return FALSE;
-	}
-	pView->m_pToolBar->SetBarStyle(pView->m_pToolBar->GetBarStyle() | CBRS_TOOLTIPS | CBRS_FLYBY);
-
-/*
-	pView->m_pToolBar = new CDialogBar;
-	if (!pView->m_pToolBar->Create(pParent, MAKEINTRESOURCE(nIDResource),
-		CBRS_TOP, AFX_IDW_PREVIEW_BAR))
-	{
-		TRACE0("Error: Preview could not create toolbar dialog.\n");
-		pParent->OnSetPreviewMode(FALSE, pState);   // restore Frame Window
-		delete pView->m_pToolBar;       // not autodestruct yet
-		pView->m_pToolBar = NULL;
-		pView->m_pPreviewState = NULL;  // do not delete state structure
-		delete pView;
-		return FALSE;
-	}
-*/	pView->m_pToolBar->m_bAutoDelete = TRUE;    // automatic cleanup
-
-	// Create the preview view as a child of the App Main Window.  This
-	// is a sibling of this view if this is an SDI app.  This is NOT a sibling
-	// if this is an MDI app.
-
-	if (!pView->Create(NULL, NULL, AFX_WS_DEFAULT_VIEW,
-		CRect(0,0,0,0), pParent, AFX_IDW_PANE_FIRST, &context))
-	{
-		TRACE0("Error: couldn't create preview view for frame.\n");
-		pParent->OnSetPreviewMode(FALSE, pState);   // restore Frame Window
-		pView->m_pPreviewState = NULL;  // do not delete state structure
-		delete pView;
-		return FALSE;
-	}
-
-	// Preview window shown now
-
-	pState->pViewActiveOld = pParent->GetActiveView();
-	CCADView* pActiveView = (CCADView*)pParent->GetActiveFrame()->GetActiveView();
-	if (pActiveView != NULL)
-		pActiveView->OnActivateView(FALSE, pActiveView, pActiveView);
-
-	if (!pView->SetPrintView((CCADView*)pPrintView))
-	{
-		pView->OnPreviewClose();
-		return TRUE;            // signal that OnEndPrintPreview was called
-	}
-
-	pParent->SetActiveView(pView);  // set active view - even for MDI
-
-	// update toolbar and redraw everything
-	pView->m_pToolBar->SendMessage(WM_IDLEUPDATECMDUI, (WPARAM)TRUE);
-	pParent->RecalcLayout();            // position and size everything
-	pParent->UpdateWindow();
-
-	return TRUE;
-}
-
 /////////////////////////////////////////////////////////////////////////////
 // CCADView diagnostics
 
@@ -741,11 +510,17 @@ int CCADView::OnCreate(LPCREATESTRUCT lpCreateStruct)
 	if (CView::OnCreate(lpCreateStruct) == -1)
 		return -1;
 
-	m_pView = new View (lcGetActiveProject(), NULL);
-	m_pView->Create (m_hWnd);
-	m_pView->OnInitialUpdate ();
+	Project* project = lcGetActiveProject();
 
-	SetTimer (IDT_LC_SAVETIMER, 5000, NULL);
+	m_pView = new View(project, project->m_ActiveView);
+	if (project->m_ActiveView)
+		m_pView->m_Camera = project->m_ActiveView->m_Camera;
+	else
+		m_pView->m_Camera = project->GetCamera(LC_CAMERA_MAIN);
+	m_pView->CreateFromWindow(m_hWnd);
+	m_pView->OnInitialUpdate();
+
+	SetTimer(IDT_LC_SAVETIMER, 5000, NULL);
 
 	return 0;
 }
@@ -755,12 +530,12 @@ void CCADView::OnDestroy()
 	delete m_pView;
 	m_pView = NULL;
 
-	KillTimer (IDT_LC_SAVETIMER);
+	KillTimer(IDT_LC_SAVETIMER);
 
 	CView::OnDestroy();
 }
 
-void CCADView::OnDropDown (NMHDR* pNotifyStruct, LRESULT* pResult)
+void CCADView::OnDropDown(NMHDR* pNotifyStruct, LRESULT* pResult)
 {
 	NMTOOLBAR* pNMToolBar = (NMTOOLBAR*)pNotifyStruct;
 	RECT rc;
@@ -858,28 +633,7 @@ BOOL CCADView::OnMouseWheel(UINT nFlags, short zDelta, CPoint pt)
 
 void CCADView::OnMButtonDown(UINT nFlags, CPoint point) 
 {
-	BOOL bCtl = GetKeyState(VK_CONTROL) & 0x8000;
-	if(!bCtl && nFlags == MK_MBUTTON)
-	{
-		CWheelWnd *pwndPanWindow = new CWheelWnd(point);
-		if (!pwndPanWindow->Create(this))
-			delete pwndPanWindow;
-	}
-	else
-		CView::OnMButtonDown(nFlags, point);
-}
-
-// Notification from the auto-pan window
-LONG CCADView::OnAutoPan(UINT lParam, LONG wParam)
-{
-	CPoint pt1(lParam), pt2(wParam);
-	pt2 -= pt1;
-	pt2.y = -pt2.y;
-
-	unsigned long pt = ((short)pt2.x) | ((unsigned long)(((short)pt2.y) << 16));
-	lcGetActiveProject()->HandleCommand(LC_VIEW_AUTOPAN, pt);	
-
-	return TRUE;
+	CView::OnMButtonDown(nFlags, point);
 }
 
 void CCADView::OnTimer(UINT nIDEvent) 
@@ -907,118 +661,63 @@ void CCADView::OnCaptureChanged(CWnd *pWnd)
 	CView::OnCaptureChanged(pWnd);
 }
 
-
-
-
-
-
-
-
-
 void CCADView::OnKeyDown(UINT nChar, UINT nRepCnt, UINT nFlags) 
 {
 	char nKey = nChar;
 
-	switch (nChar)
-	{
-		case VK_NUMPAD0 : case VK_NUMPAD1 : case VK_NUMPAD2 : case VK_NUMPAD3 : case VK_NUMPAD4 : 
-		case VK_NUMPAD5 : case VK_NUMPAD6 : case VK_NUMPAD7 : case VK_NUMPAD8 : case VK_NUMPAD9 :
-		{
-			nKey = nChar - VK_NUMPAD0 + 0x30;
-		} break;
-
-    // select the next/previous piece on the pieces list
-    case VK_HOME:
-    case VK_END:
+	if (nChar >= VK_NUMPAD0 && nChar <= VK_NUMPAD9)
     {
-      /*
-      CMainFrame* pMain = (CMainFrame*)AfxGetMainWnd ();
-      CPiecesList& pList = pMain->m_wndPiecesBar.m_wndPiecesList;
-      LV_FINDINFO lvfi;
-      int sel;
-
-			lvfi.flags = LVFI_PARAM;
-			lvfi.lParam = (LPARAM)pMain->m_wndPiecesBar.m_wndPiecePreview.GetPieceInfo ();
-			sel = pList.FindItem (&lvfi);
-
-      if (sel != -1)
-      {
-        if (nChar == VK_HOME)
-          sel--;
-        else
-          sel++;
-
-  			pList.SetItemState (sel, LVIS_SELECTED|LVIS_FOCUSED, LVIS_SELECTED|LVIS_FOCUSED);
-	  		pList.EnsureVisible (sel, FALSE);
-      }
-*/
-    } break;
+		nKey = nChar - VK_NUMPAD0 + '0';
 	}
 
-	lcGetActiveProject()->OnKeyDown(nKey, GetKeyState (VK_CONTROL) < 0, GetKeyState (VK_SHIFT) < 0);
-/*
-	switch (nChar)
+	// Update cursor for multiple selection.
+	if (nChar == VK_CONTROL)
 	{
-// HANDLE CTRL if action == pan/zoom
-		case VK_CONTROL: 
-		if (m_nCurAction == ACTION_SELECT)
+		if (lcGetActiveProject()->GetAction() == LC_ACTION_SELECT)
 		{
 			POINT pt;
+
 			GetCursorPos(&pt);
 			CRect rc;
 			GetWindowRect(rc);
+
 			if (rc.PtInRect(pt))
 				OnSetCursor(this, HTCLIENT, 0);
-		} break;
-*/
+		}
+	}
+
+	lcGetActiveProject()->OnKeyDown(nKey, GetKeyState (VK_CONTROL) < 0, GetKeyState (VK_SHIFT) < 0);
+
 	CView::OnKeyDown(nChar, nRepCnt, nFlags);
 }
 
 void CCADView::OnKeyUp(UINT nChar, UINT nRepCnt, UINT nFlags) 
 {
-/*	if (nChar == VK_CONTROL)
+	// Update cursor for multiple selection.
+	if (nChar == VK_CONTROL)
 	{
-// HANDLE CTRL if action == pan/zoom
-		CCADDoc* pDoc = GetDocument();
-		if (pDoc->m_nCurAction == ACTION_SELECT)
+		if (lcGetActiveProject()->GetAction() == LC_ACTION_SELECT)
 		{
 			POINT pt;
+
 			GetCursorPos(&pt);
 			CRect rc;
 			GetWindowRect(rc);
+
 			if (rc.PtInRect(pt))
 				OnSetCursor(this, HTCLIENT, 0);
 		}
 	}
-*/	
+
 	CView::OnKeyUp(nChar, nRepCnt, nFlags);
 }
 
 void CCADView::OnActivateView(BOOL bActivate, CView* pActivateView, CView* pDeactiveView) 
 {
-	CView::OnActivateView(bActivate, pActivateView, pDeactiveView);
-/*
-	if (IsWindowEnabled())
-	{
-		if (bActivate)
-		{
-			if (m_pPixels)
-				free (m_pPixels);
-			m_pPixels = NULL;
-		}
-		else
-		{
-			if (m_pPixels)
-				free (m_pPixels);
+//	if (pActivateView && pActivateView->IsKindOf(RUNTIME_CLASS(CCADView)))
+//		lcGetActiveProject()->SetActiveView(((CCADView*)pActivateView)->m_pView);
 
-			CCADDoc* pDoc = GetDocument();
-			m_pPixels = malloc(pDoc->m_szView.cx * pDoc->m_szView.cy * sizeof(GLubyte) * 4);
-			if (!m_pPixels)
-				return;
-			glReadPixels(0, 0, pDoc->m_szView.cx, pDoc->m_szView.cy, GL_RGBA, GL_UNSIGNED_BYTE, m_pPixels);
-		}
-	}
-*/
+	CView::OnActivateView(bActivate, pActivateView, pDeactiveView);
 }
 
 LRESULT CCADView::WindowProc(UINT message, WPARAM wParam, LPARAM lParam) 
