@@ -1,6 +1,9 @@
 #ifndef _LIBDLG_H_
 #define _LIBDLG_H_
 
+#include "array.h"
+#include "str.h"
+
 class PieceInfo;
 
 class CLibraryDlg : public CDialog
@@ -33,6 +36,8 @@ public:
 	void UpdateTree();
 	void UpdateList();
 
+	bool ImportPieces(const ObjArray<String>& FileList);
+
 	CToolBar m_wndToolBar;
 	CImageList m_TreeImages;
 	int m_SortColumn;
