@@ -29,7 +29,6 @@ CPreferencesGeneral::CPreferencesGeneral() : CPropertyPage(CPreferencesGeneral::
 	//{{AFX_DATA_INIT(CPreferencesGeneral)
 	m_bSubparts = FALSE;
 	m_nSaveTime = 0;
-	m_bNumbers = FALSE;
 	m_strFolder = _T("");
 	m_bAutoSave = FALSE;
 	m_strUser = _T("");
@@ -46,10 +45,8 @@ void CPreferencesGeneral::DoDataExchange(CDataExchange* pDX)
 	CPropertyPage::DoDataExchange(pDX);
 	//{{AFX_DATA_MAP(CPreferencesGeneral)
 	DDX_Control(pDX, IDC_GENDLG_MOUSE, m_ctlMouse);
-	DDX_Check(pDX, IDC_GENDLG_SUBPARTS, m_bSubparts);
 	DDX_Text(pDX, IDC_GENDLG_SAVETIME, m_nSaveTime);
 	DDV_MinMaxInt(pDX, m_nSaveTime, 1, 60);
-	DDX_Check(pDX, IDC_GENDLG_NUMBERS, m_bNumbers);
 	DDX_Text(pDX, IDC_GENDLG_FOLDER, m_strFolder);
 	DDX_Check(pDX, IDC_GENDLG_AUTOSAVE, m_bAutoSave);
 	DDX_Text(pDX, IDC_GENDLG_USER, m_strUser);
@@ -87,7 +84,6 @@ void CPreferencesGeneral::SetOptions(int nSaveInterval, int nMouse, const char*
 	m_Updates = AfxGetApp()->GetProfileInt("Settings", "CheckUpdates", 1);
 	int i = AfxGetApp()->GetProfileInt("Settings", "Piecebar Options", 0);
 	m_bSubparts = (i & PIECEBAR_SUBPARTS) != 0;
-	m_bNumbers = (i & PIECEBAR_PARTNUMBERS) != 0;
 }
 
 void CPreferencesGeneral::GetOptions(int* nSaveTime, int* nMouse, char* strFolder, char* strUser)
@@ -100,7 +96,6 @@ void CPreferencesGeneral::GetOptions(int* nSaveTime, int* nMouse, char* strFolde
 
 	int i = 0;
 	if (m_bSubparts) i |= PIECEBAR_SUBPARTS;
-	if (m_bNumbers) i |= PIECEBAR_PARTNUMBERS;
 		
 	AfxGetApp()->WriteProfileInt("Settings", "Piecebar Options", i);
 	AfxGetApp()->WriteProfileInt("Settings", "CheckUpdates", m_Updates);
@@ -130,16 +125,11 @@ CPreferencesDetail::CPreferencesDetail() : CPropertyPage(CPreferencesDetail::IDD
 {
 	//{{AFX_DATA_INIT(CPreferencesDetail)
 	m_bAntialiasing = FALSE;
-	m_bDithering = FALSE;
 	m_bEdges = FALSE;
 	m_bLighting = FALSE;
-	m_bLinear = FALSE;
 	m_bSmooth = FALSE;
 	m_fLineWidth = 0.0f;
-	m_bBackground = FALSE;
 	m_bFast = FALSE;
-	m_bHidden = FALSE;
-	m_bSolid = FALSE;
 	//}}AFX_DATA_INIT
 }
 
@@ -152,49 +142,29 @@ void CPreferencesDetail::DoDataExchange(CDataExchange* pDX)
 	CPropertyPage::DoDataExchange(pDX);
 	//{{AFX_DATA_MAP(CPreferencesDetail)
 	DDX_Check(pDX, IDC_DETDLG_ANTIALIAS, m_bAntialiasing);
-	DDX_Check(pDX, IDC_DETDLG_DITHER, m_bDithering);
 	DDX_Check(pDX, IDC_DETDLG_EDGES, m_bEdges);
 	DDX_Check(pDX, IDC_DETDLG_LIGHTING, m_bLighting);
-	DDX_Check(pDX, IDC_DETDLG_LINEAR, m_bLinear);
 	DDX_Check(pDX, IDC_DETDLG_SMOOTH, m_bSmooth);
 	DDX_Text(pDX, IDC_DETDLG_LINE, m_fLineWidth);
 	DDV_MinMaxFloat(pDX, m_fLineWidth, 0.f, 10.f);
-	DDX_Check(pDX, IDC_DETDLG_BACKGROUND, m_bBackground);
 	DDX_Check(pDX, IDC_DETDLG_FAST, m_bFast);
-	DDX_Check(pDX, IDC_DETDLG_HIDDEN, m_bHidden);
-	DDX_Check(pDX, IDC_DETDLG_SOLID, m_bSolid);
 	//}}AFX_DATA_MAP
 }
 
 
 BEGIN_MESSAGE_MAP(CPreferencesDetail, CPropertyPage)
 	//{{AFX_MSG_MAP(CPreferencesDetail)
-	ON_BN_CLICKED(IDC_DETDLG_FAST, OnFastClick)
-	ON_BN_CLICKED(IDC_DETDLG_SOLID, OnDetdlgSolid)
 	//}}AFX_MSG_MAP
 END_MESSAGE_MAP()
 
 
-BOOL CPreferencesDetail::OnInitDialog() 
-{
-	CPropertyPage::OnInitDialog();
-	OnFastClick();
-	OnDetdlgSolid();
-	return TRUE;
-}
-
 void CPreferencesDetail::SetOptions(DWORD dwDetail, float fLine)
 {
 	m_bAntialiasing = (dwDetail & LC_DET_ANTIALIAS) != 0;
-	m_bDithering = (dwDetail & LC_DET_DITHER) != 0;
 	m_bEdges = (dwDetail & LC_DET_BRICKEDGES) != 0;
 	m_bLighting = (dwDetail & LC_DET_LIGHTING) != 0;
-	m_bLinear =	(dwDetail & LC_DET_LINEAR) != 0;
 	m_bSmooth =	(dwDetail & LC_DET_SMOOTH) != 0;
-	m_bBackground = (dwDetail & LC_DET_BACKGROUND) != 0;
 	m_bFast = (dwDetail & LC_DET_FAST) != 0;
-	m_bHidden = (dwDetail & LC_DET_HIDDEN_LINE) != 0;
-	m_bSolid = (dwDetail & LC_DET_BOX_FILL) != 0;
 	m_fLineWidth = fLine;
 }
 
@@ -202,37 +172,13 @@ void CPreferencesDetail::GetOptions(DWORD* dwDetail, float* fLine)
 {
 	*dwDetail = 0;
 	if (m_bAntialiasing) *dwDetail |= LC_DET_ANTIALIAS;
-	if (m_bDithering) *dwDetail |= LC_DET_DITHER;
 	if (m_bEdges) *dwDetail |= LC_DET_BRICKEDGES;
 	if (m_bLighting) *dwDetail |= LC_DET_LIGHTING;
-	if (m_bLinear) *dwDetail |= LC_DET_LINEAR;
 	if (m_bSmooth) *dwDetail |= LC_DET_SMOOTH;
-	if (m_bBackground) *dwDetail |= LC_DET_BACKGROUND;
 	if (m_bFast) *dwDetail |= LC_DET_FAST;
-	if (m_bHidden) *dwDetail |= LC_DET_HIDDEN_LINE;
-	if (m_bSolid) *dwDetail |= LC_DET_BOX_FILL;
 	*fLine = m_fLineWidth;
 }
 
-void CPreferencesDetail::OnFastClick() 
-{
-	UpdateData (TRUE);
-	if (m_bFast)
-		GetDlgItem (IDC_DETDLG_BACKGROUND)->EnableWindow(TRUE);
-	else
-	{
-		m_bBackground = FALSE;
-		UpdateData(FALSE);
-		GetDlgItem (IDC_DETDLG_BACKGROUND)->EnableWindow(FALSE);
-	}
-}
-
-void CPreferencesDetail::OnDetdlgSolid() 
-{
-	UpdateData (TRUE);
-	GetDlgItem (IDC_DETDLG_HIDDEN)->EnableWindow(!m_bSolid);
-}
-
 /////////////////////////////////////////////////////////////////////////////
 // CPreferencesDrawing property page
 
@@ -382,6 +328,8 @@ BEGIN_MESSAGE_MAP(CPreferencesScene, CPropertyPage)
 	//}}AFX_MSG_MAP
 END_MESSAGE_MAP()
 
+#define COLOR_BTN_WIDTH 30
+#define COLOR_BTN_HEIGHT 14
 
 void CPreferencesScene::OnBackgroundBrowse() 
 {
@@ -401,7 +349,7 @@ void CPreferencesScene::OnBackgroundColor()
 	if (dlg.DoModal() == IDOK)
 	{
 		m_crBackground = dlg.GetColor();
-		DeleteObject(m_btnBackground.SetBitmap(CreateColorBitmap (20, 10, m_crBackground)));
+		DeleteObject(m_btnBackground.SetBitmap(CreateColorBitmap(COLOR_BTN_WIDTH, COLOR_BTN_HEIGHT, m_crBackground)));
 	}
 }
 
@@ -411,7 +359,7 @@ void CPreferencesScene::OnAmbientLight()
 	if (dlg.DoModal() == IDOK)
 	{
 		m_crAmbient = dlg.GetColor();
-		DeleteObject(m_btnAmbient.SetBitmap(CreateColorBitmap (20, 10, m_crAmbient)));
+		DeleteObject(m_btnAmbient.SetBitmap(CreateColorBitmap(COLOR_BTN_WIDTH, COLOR_BTN_HEIGHT, m_crAmbient)));
 	}
 }
 
@@ -421,7 +369,7 @@ void CPreferencesScene::OnFogColor()
 	if (dlg.DoModal() == IDOK)
 	{
 		m_crFog = dlg.GetColor();
-		DeleteObject(m_btnFog.SetBitmap(CreateColorBitmap (20, 10, m_crFog)));
+		DeleteObject(m_btnFog.SetBitmap(CreateColorBitmap(COLOR_BTN_WIDTH, COLOR_BTN_HEIGHT, m_crFog)));
 	}
 }
 
@@ -431,7 +379,7 @@ void CPreferencesScene::OnGradColor1()
 	if (dlg.DoModal() == IDOK)
 	{
 		m_crGrad1 = dlg.GetColor();
-		DeleteObject(m_btnGrad1.SetBitmap(CreateColorBitmap (20, 10, m_crGrad1)));
+		DeleteObject(m_btnGrad1.SetBitmap(CreateColorBitmap(COLOR_BTN_WIDTH, COLOR_BTN_HEIGHT, m_crGrad1)));
 	}
 }
 
@@ -441,7 +389,7 @@ void CPreferencesScene::OnGradColor2()
 	if (dlg.DoModal() == IDOK)
 	{
 		m_crGrad2 = dlg.GetColor();
-		DeleteObject(m_btnGrad2.SetBitmap(CreateColorBitmap (20, 10, m_crGrad2)));
+		DeleteObject(m_btnGrad2.SetBitmap(CreateColorBitmap(COLOR_BTN_WIDTH, COLOR_BTN_HEIGHT, m_crGrad2)));
 	}
 }
 
@@ -449,11 +397,11 @@ BOOL CPreferencesScene::OnInitDialog()
 {
 	CPropertyPage::OnInitDialog();
 
-	m_btnAmbient.SetBitmap(CreateColorBitmap (20, 10, m_crAmbient));
-	m_btnBackground.SetBitmap(CreateColorBitmap (20, 10, m_crBackground));
-	m_btnFog.SetBitmap(CreateColorBitmap (20, 10, m_crFog));
-	m_btnGrad1.SetBitmap(CreateColorBitmap (20, 10, m_crGrad1));
-	m_btnGrad2.SetBitmap(CreateColorBitmap (20, 10, m_crGrad2));
+	m_btnAmbient.SetBitmap(CreateColorBitmap(COLOR_BTN_WIDTH, COLOR_BTN_HEIGHT, m_crAmbient));
+	m_btnBackground.SetBitmap(CreateColorBitmap(COLOR_BTN_WIDTH, COLOR_BTN_HEIGHT, m_crBackground));
+	m_btnFog.SetBitmap(CreateColorBitmap(COLOR_BTN_WIDTH, COLOR_BTN_HEIGHT, m_crFog));
+	m_btnGrad1.SetBitmap(CreateColorBitmap(COLOR_BTN_WIDTH, COLOR_BTN_HEIGHT, m_crGrad1));
+	m_btnGrad2.SetBitmap(CreateColorBitmap(COLOR_BTN_WIDTH, COLOR_BTN_HEIGHT, m_crGrad2));
 	
 	return TRUE;
 }
