@@ -5,7 +5,6 @@
 #include <dlgs.h>
 #include <direct.h>
 #include "leocad.h"
-#include "bmpmenu.h"
 #include "system.h"
 #include "defines.h"
 #include "camera.h"
@@ -52,8 +51,6 @@ bool lcAssert(const char* FileName, int Line, const char* Expression, const char
 	return false;
 }
 
-
-static CMenu menuPopups;
 static CStepDlg* StepModeless = NULL;
 static UINT ClipboardFormat = 0;
 
@@ -73,12 +70,12 @@ static void ShowLastError()
 
 static CMenu* GetMainMenu(int nIndex)
 {
-	CWnd* pFrame = AfxGetMainWnd();
+	CMainFrame* pFrame = (CMainFrame*)AfxGetMainWnd();
 
 	if (pFrame == NULL)
 		return NULL;
 
-	CMenu* pMenu = pFrame->GetMenu();
+	CMenu* pMenu =  CMenu::FromHandle(pFrame->m_wndMenuBar.GetHMenu());
 
 	if (pMenu == NULL)
 		return NULL;
@@ -341,25 +338,15 @@ void SystemDoWaitCursor(int nCode)
 }
 
 void Sys_BeginWait ()
-
 {
-
-  SystemDoWaitCursor (1);
-
+	SystemDoWaitCursor (1);
 }
 
-
-
 void Sys_EndWait ()
-
 {
-
-  SystemDoWaitCursor (-1);
-
+	SystemDoWaitCursor (-1);
 }
 
-
-
 /////////////////////////////////////////////////////////////////////////////
 // Profile Access
 
@@ -408,72 +395,39 @@ void SystemInit()
 	// initialize wait cursor state
 	g_nWaitCursorCount = 0;
 	g_hcurWaitCursorRestore = NULL;
-
-	menuPopups.LoadMenu(IDR_POPUPS);
-
-	// attempt to load special bitmap, else default to arrow
-	CSize size = GetMenuCheckMarkDimensions();
-	ASSERT(size.cx > 4 && size.cy > 5); // not too small please
-	if (size.cx > 32)
-		size.cx = 32;
-	int iwRow = (size.cx + 15) >> 4;    // # of WORDs per raster line
-	int nShift = (size.cx - DOT_WIDTH) / 2;     // # of bits to shift over
-	nShift += ((iwRow * 16) - size.cx); // padding for word alignment
-	if (nShift > 16 - DOT_WIDTH)
-		nShift = 16 - DOT_WIDTH;    // maximum shift for 1 word
-
-	if (size.cy > 32)
-		size.cy = 32;
-
-	// bitmap 2/4/4/4/2 pixels wide - centered (0 => black)
-	BYTE rgbBitmap[32 * 2 * sizeof(WORD)];
-	memset(rgbBitmap, 0xff, sizeof(rgbBitmap));
-
-	BYTE* pbOut = &rgbBitmap[iwRow * sizeof(WORD) *
-							((size.cy - (DOT_HEIGHT+1)) >> 1)];
-	const BYTE* pbIn = rgbDot;
-	for (int y = 0; y < DOT_HEIGHT; y++)
-	{
-		WORD w = (WORD)~(((DWORD)*pbIn++) << nShift);
-		// bitmaps are always hi-lo
-		pbOut[0] = HIBYTE(w);
-		pbOut[1] = LOBYTE(w);
-		pbOut += iwRow * sizeof(WORD);
-	}
-
-	hbmMenuDot = CreateBitmap(size.cx, size.cy, 1, 1, (LPVOID)&rgbBitmap);
-	if (hbmMenuDot == NULL)
-	{
-		#define OBM_MNARROW         32739
-		hbmMenuDot = LoadBitmap(NULL, MAKEINTRESOURCE(OBM_MNARROW));
-	}
 }
 
-// Viewport menu.
-void SystemUpdateViewport(int nNew, int nOld)
+static void CheckToolBarButton(CMFCToolBar& ToolBar, int ID, bool Check)
 {
-	CMenu* pMenu = GetMainMenu(2);
-	if (!pMenu)
-		return;
-	pMenu = pMenu->GetSubMenu(13);
-	pMenu->CheckMenuItem(nOld + ID_VIEWPORT01, MF_BYCOMMAND | MF_UNCHECKED);
-	pMenu->CheckMenuItem(nNew + ID_VIEWPORT01, MF_BYCOMMAND | MF_CHECKED);
+	int Index = ToolBar.CommandToIndex(ID);
+	UINT NewStyle = ToolBar.GetButtonStyle(Index) & ~(TBBS_CHECKED | TBBS_INDETERMINATE);
+	if (Check)
+		NewStyle |= TBBS_CHECKED;
+	ToolBar.SetButtonStyle(Index, NewStyle | TBBS_CHECKBOX);
+}
+
+static void EnableToolBarButton(CMFCToolBar& ToolBar, int ID, bool Enable)
+{
+	int Index = ToolBar.CommandToIndex(ID);
+	UINT NewStyle = ToolBar.GetButtonStyle(Index) & ~TBBS_DISABLED;
+
+	if (!Enable)
+		NewStyle |= TBBS_DISABLED;
+	ToolBar.SetButtonStyle(Index, NewStyle);
 }
 
 // Action toolbar, popup menu and cursor.
 void SystemUpdateAction(int nNew, int nOld)
 {
-	CFrameWnd* pFrame = (CFrameWnd*)AfxGetMainWnd();
+	CMainFrame* pFrame = (CMainFrame*)AfxGetMainWnd();
 	if (!pFrame)
 		return;
-	CToolBar* pBar = (CToolBar*)pFrame->GetControlBar(ID_VIEW_TOOLS_BAR);
-	CToolBarCtrl* pCtrl = &pBar->GetToolBarCtrl();
-	CView* pView = pFrame->GetActiveView();
 
-	pCtrl->CheckButton(ID_ACTION_SELECT+nOld, FALSE);
-	pCtrl->CheckButton(ID_ACTION_SELECT+nNew, TRUE);
+//	CheckToolBarButton(pFrame->m_wndToolsBar, ID_ACTION_SELECT+nOld, FALSE);
+//	CheckToolBarButton(pFrame->m_wndToolsBar, ID_ACTION_SELECT+nNew, TRUE);
 
 	// TODO: make sure this works if loading a file from the cmd line.
+	CView* pView = pFrame->GetActiveView();
 	if (pView)
 		pView->SendMessage(WM_LC_SET_CURSOR, nNew);
 
@@ -484,176 +438,225 @@ void SystemUpdateAction(int nNew, int nOld)
 // Current color in the listbox;
 void SystemUpdateColorList(int nNew)
 {
-	if (AfxGetMainWnd())
-		AfxGetMainWnd()->PostMessage (WM_LC_UPDATE_LIST, 0, nNew+1);
-}
-
-void SystemUpdateRenderingMode(bool bBackground, bool bFast)
-{
-	CFrameWnd* pFrame = (CFrameWnd*)AfxGetMainWnd();
+	CMainFrame* pFrame = (CMainFrame*)AfxGetMainWnd();
 	if (!pFrame)
 		return;
-	CToolBar* pBar = (CToolBar*)pFrame->GetControlBar(AFX_IDW_TOOLBAR);
-	CToolBarCtrl* pCtrl = &pBar->GetToolBarCtrl();
 
-//	if (bFast)
-//	{
-//		pCtrl->EnableButton(ID_RENDER_BACKGROUND, TRUE);
-//		pCtrl->CheckButton(ID_RENDER_BACKGROUND, bBackground);
-//	}
-//	else
-	{
-		pCtrl->CheckButton(ID_RENDER_BACKGROUND, FALSE);
-		pCtrl->EnableButton(ID_RENDER_BACKGROUND, FALSE);
-	}
+	pFrame->PostMessage (WM_LC_UPDATE_LIST, 0, nNew+1);
+}
 
-	pCtrl->CheckButton(ID_RENDER_BOX, bFast);
+void SystemUpdateRenderingMode(bool bFast)
+{
+	CMainFrame* pFrame = (CMainFrame*)AfxGetMainWnd();
+	if (!pFrame)
+		return;
+
+	CheckToolBarButton(pFrame->m_wndStandardBar, ID_RENDER_BOX, bFast);
 }
 
 void SystemUpdateUndoRedo(char* undo, char* redo)
 {
-	CFrameWnd* pFrame = (CFrameWnd*)AfxGetMainWnd();
+	CMainFrame* pFrame = (CMainFrame*)AfxGetMainWnd();
 	if (!pFrame)
 		return;
-	CToolBar* pBar = (CToolBar*)pFrame->GetControlBar(AFX_IDW_TOOLBAR);
-	CToolBarCtrl* pCtrl = &pBar->GetToolBarCtrl();
-	CMenu* pMenu = GetMainMenu(1);
-	char txt[50];
-	UINT nState;
 
-	if (pMenu == NULL)
-		return;
+	EnableToolBarButton(pFrame->m_wndStandardBar, ID_EDIT_UNDO, undo != NULL);
+	EnableToolBarButton(pFrame->m_wndStandardBar, ID_EDIT_REDO, redo != NULL);
 
-	strcpy(txt, "Undo ");
-	if (undo != NULL)
-		strcat(txt, undo);
-	strcat(txt, "\tCtrl+Z");
+	CMFCMenuBar& MenuBar = pFrame->m_wndMenuBar;
+	CMFCToolBarButton* pEditButton = MenuBar.GetButton(1);
+	CMFCToolBarMenuButton* pEditMenuButton = DYNAMIC_DOWNCAST(CMFCToolBarMenuButton, pEditButton);
 
-	nState = pMenu->GetMenuState(ID_EDIT_UNDO, MF_BYCOMMAND);
-	nState &= ~(MF_BITMAP|MF_OWNERDRAW|MF_SEPARATOR);
-	pMenu->ModifyMenu(ID_EDIT_UNDO, MF_BYCOMMAND |
-        MF_STRING | nState, ID_EDIT_UNDO, txt);
+	const CObList& editCommands = pEditMenuButton->GetCommands();
 
-	strcpy(txt, "Redo ");
-	if (redo != NULL)
-		strcat(txt, redo);
-	strcat(txt, "\tCtrl+Y");
+	for (POSITION pos = editCommands.GetHeadPosition (); pos != NULL;)
+	{
+		CMFCToolBarButton* pSubButton = (CMFCToolBarButton*)editCommands.GetNext(pos);
+		ASSERT_VALID(pSubButton);
 
-	nState = pMenu->GetMenuState(ID_EDIT_REDO, MF_BYCOMMAND);
-	nState &= ~(MF_BITMAP|MF_OWNERDRAW|MF_SEPARATOR);
-	pMenu->ModifyMenu(ID_EDIT_REDO, MF_BYCOMMAND |
-        MF_STRING | nState, ID_EDIT_REDO, txt);
+		UINT Style = pSubButton->m_nStyle;
 
-	pMenu->EnableMenuItem(ID_EDIT_UNDO, MF_BYCOMMAND | 
-		(undo ? MF_ENABLED : (MF_DISABLED | MF_GRAYED)));
-	pMenu->EnableMenuItem(ID_EDIT_REDO, MF_BYCOMMAND | 
-		(redo ? MF_ENABLED : (MF_DISABLED | MF_GRAYED)));
+		switch (pSubButton->m_nID)
+		{
+		case ID_EDIT_UNDO:
+			if (undo)
+			{
+				pSubButton->SetStyle(Style & ~TBBS_DISABLED);
+				pSubButton->m_strText = "Undo " + CString(undo);
+			}
+			else
+			{
+				pSubButton->SetStyle(Style | TBBS_DISABLED);
+				pSubButton->m_strText = "Undo";
+			}
+			break;
 
-	pCtrl->EnableButton(ID_EDIT_UNDO, undo ? TRUE : FALSE);
-	pCtrl->EnableButton(ID_EDIT_REDO, redo ? TRUE : FALSE);
+		case ID_EDIT_REDO:
+			if (redo)
+			{
+				pSubButton->SetStyle(Style & ~TBBS_DISABLED);
+				pSubButton->m_strText = "Redo " + CString(redo);
+			}
+			else
+			{
+				pSubButton->SetStyle(Style | TBBS_DISABLED);
+				pSubButton->m_strText = "Redo";
+			}
+			break;
+		}
+	}
 }
 
-// Snap menu & toolbar icon
 void SystemUpdateSnap(const unsigned long nSnap)
 {
-	CFrameWnd* pFrame = (CFrameWnd*)AfxGetMainWnd();
+	CMainFrame* pFrame = (CMainFrame*)AfxGetMainWnd();
 	if (!pFrame)
 		return;
-	CToolBar* pBar = (CToolBar*)pFrame->GetControlBar(AFX_IDW_TOOLBAR);
-	CToolBarCtrl* pCtrl = &pBar->GetToolBarCtrl();
-	pCtrl->CheckButton(ID_SNAP_ANGLE, (nSnap & LC_DRAW_SNAP_A) != 0);
 
-	CMenu* pMenu = menuPopups.GetSubMenu(2);
-	pMenu->CheckMenuItem(ID_SNAP_SNAPX, MF_BYCOMMAND | 
-		(nSnap & LC_DRAW_SNAP_X ? MF_CHECKED : MF_UNCHECKED));
-	pMenu->CheckMenuItem(ID_SNAP_SNAPY, MF_BYCOMMAND | 
-		(nSnap & LC_DRAW_SNAP_Y ? MF_CHECKED : MF_UNCHECKED));
-	pMenu->CheckMenuItem(ID_SNAP_SNAPZ, MF_BYCOMMAND | 
-		(nSnap & LC_DRAW_SNAP_Z ? MF_CHECKED : MF_UNCHECKED));
-
-	pMenu = menuPopups.GetSubMenu(8);
-	pMenu->CheckMenuItem(ID_LOCK_LOCKX, MF_BYCOMMAND | 
-		(nSnap & LC_DRAW_LOCK_X ? MF_CHECKED : MF_UNCHECKED));
-	pMenu->CheckMenuItem(ID_LOCK_LOCKY, MF_BYCOMMAND | 
-		(nSnap & LC_DRAW_LOCK_Y ? MF_CHECKED : MF_UNCHECKED));
-	pMenu->CheckMenuItem(ID_LOCK_LOCKZ, MF_BYCOMMAND | 
-		(nSnap & LC_DRAW_LOCK_Z ? MF_CHECKED : MF_UNCHECKED));
-
-	SetMenuItemBitmaps(pMenu->m_hMenu, ID_LOCK_2BUTTONS, MF_BYCOMMAND, NULL, hbmMenuDot);
-	SetMenuItemBitmaps(pMenu->m_hMenu, ID_LOCK_3DMOVEMENT, MF_BYCOMMAND, NULL, hbmMenuDot);
-
-	// TODO: change Snap None & All (or maybe not ?)
+	CheckToolBarButton(pFrame->m_wndStandardBar, ID_SNAP_ANGLE, (nSnap & LC_DRAW_SNAP_A) != 0);
 }
 
 void SystemUpdateSelected(unsigned long flags, int SelectedCount, Object* Focus)
 {
-	CMenu* pMenu;
 	CMainFrame* pFrame = (CMainFrame*)AfxGetMainWnd();
 	if (!pFrame)
 		return;
-	CToolBar* pBar = (CToolBar*)pFrame->GetControlBar(AFX_IDW_TOOLBAR);
-	CToolBarCtrl* pCtrl = &pBar->GetToolBarCtrl();
 
-	// select all/none/invert/by name
-	pMenu = GetMainMenu(1);
-	if (flags & LC_SEL_NO_PIECES)
+	CMFCMenuBar& MenuBar = pFrame->m_wndMenuBar;
+	CMFCToolBarButton* pEditButton = MenuBar.GetButton(1);
+	CMFCToolBarMenuButton* pEditMenuButton = DYNAMIC_DOWNCAST(CMFCToolBarMenuButton, pEditButton);
+
+	const CObList& editCommands = pEditMenuButton->GetCommands();
+
+	for (POSITION pos = editCommands.GetHeadPosition (); pos != NULL;)
 	{
-		pMenu->EnableMenuItem(ID_EDIT_SELECTINVERT, MF_BYCOMMAND | MF_DISABLED | MF_GRAYED);
-		pMenu->EnableMenuItem(ID_EDIT_SELECTBYNAME, MF_BYCOMMAND | MF_DISABLED | MF_GRAYED);
+		CMFCToolBarButton* pSubButton = (CMFCToolBarButton*)editCommands.GetNext(pos);
+		ASSERT_VALID(pSubButton);
+
+		UINT Style = pSubButton->m_nStyle;
+
+		switch (pSubButton->m_nID)
+		{
+		case ID_EDIT_CUT:
+		case ID_EDIT_COPY:
+			if (flags & (LC_SEL_PIECE|LC_SEL_CAMERA|LC_SEL_LIGHT))
+				pSubButton->SetStyle(Style & ~TBBS_DISABLED);
+			else
+				pSubButton->SetStyle(Style | TBBS_DISABLED);
+			break;
+
+		case ID_EDIT_SELECTINVERT:
+		case ID_EDIT_SELECTBYNAME:
+			if (flags & LC_SEL_NO_PIECES)
+				pSubButton->SetStyle(Style | TBBS_DISABLED);
+			else
+				pSubButton->SetStyle(Style & ~TBBS_DISABLED);
+			break;
+
+		case ID_EDIT_SELECTNONE:
+			if (flags & (LC_SEL_PIECE|LC_SEL_CAMERA|LC_SEL_LIGHT))
+				pSubButton->SetStyle(Style & ~TBBS_DISABLED);
+			else
+				pSubButton->SetStyle(Style | TBBS_DISABLED);
+			break;
+
+		case ID_EDIT_SELECTALL:
+			if (flags & LC_SEL_UNSELECTED)
+				pSubButton->SetStyle(Style & ~TBBS_DISABLED);
+			else
+				pSubButton->SetStyle(Style | TBBS_DISABLED);
+			break;
+		};
+
 	}
-	else
+
+	EnableToolBarButton(pFrame->m_wndStandardBar, ID_EDIT_CUT, flags & (LC_SEL_PIECE|LC_SEL_CAMERA|LC_SEL_LIGHT) ? TRUE : FALSE);
+	EnableToolBarButton(pFrame->m_wndStandardBar, ID_EDIT_COPY, flags & (LC_SEL_PIECE|LC_SEL_CAMERA|LC_SEL_LIGHT) ? TRUE : FALSE);
+
+	CMFCToolBarButton* pPieceButton = MenuBar.GetButton(3);
+	CMFCToolBarMenuButton* pPieceMenuButton = DYNAMIC_DOWNCAST(CMFCToolBarMenuButton, pPieceButton);
+
+	const CObList& pieceCommands = pPieceMenuButton->GetCommands();
+
+	for (POSITION pos = pieceCommands.GetHeadPosition (); pos != NULL;)
 	{
-		pMenu->EnableMenuItem(ID_EDIT_SELECTINVERT, MF_BYCOMMAND | MF_ENABLED);
-		pMenu->EnableMenuItem(ID_EDIT_SELECTBYNAME, MF_BYCOMMAND | MF_ENABLED);
+		CMFCToolBarButton* pSubButton = (CMFCToolBarButton*)pieceCommands.GetNext(pos);
+		ASSERT_VALID(pSubButton);
+
+		UINT Style = pSubButton->m_nStyle;
+
+		switch (pSubButton->m_nID)
+		{
+		case ID_PIECE_DELETE:
+		case ID_PIECE_COPYKEYS:
+			if (flags & (LC_SEL_PIECE|LC_SEL_CAMERA|LC_SEL_LIGHT))
+				pSubButton->SetStyle(Style & ~TBBS_DISABLED);
+			else
+				pSubButton->SetStyle(Style | TBBS_DISABLED);
+			break;
+
+		case ID_PIECE_ARRAY:
+		case ID_PIECE_MIRROR:
+		case ID_PIECE_HIDESELECTED:
+			if (flags & LC_SEL_PIECE)
+				pSubButton->SetStyle(Style & ~TBBS_DISABLED);
+			else
+				pSubButton->SetStyle(Style | TBBS_DISABLED);
+			break;
+
+		case ID_PIECE_UNHIDEALL:
+			if (flags & LC_SEL_HIDDEN)
+				pSubButton->SetStyle(Style & ~TBBS_DISABLED);
+			else
+				pSubButton->SetStyle(Style | TBBS_DISABLED);
+			break;
+
+		case ID_PIECE_HIDEUNSELECTED:
+			if (flags & LC_SEL_UNSELECTED)
+				pSubButton->SetStyle(Style & ~TBBS_DISABLED);
+			else
+				pSubButton->SetStyle(Style | TBBS_DISABLED);
+			break;
+
+		case ID_PIECE_GROUP:
+			if (flags & LC_SEL_CANGROUP)
+				pSubButton->SetStyle(Style & ~TBBS_DISABLED);
+			else
+				pSubButton->SetStyle(Style | TBBS_DISABLED);
+			break;
+
+		case ID_PIECE_UNGROUP:
+			if (flags & LC_SEL_GROUP)
+				pSubButton->SetStyle(Style & ~TBBS_DISABLED);
+			else
+				pSubButton->SetStyle(Style | TBBS_DISABLED);
+			break;
+
+		case ID_PIECE_ATTACH:
+			if ((flags & (LC_SEL_GROUP|LC_SEL_FOCUSGROUP)) == LC_SEL_GROUP)
+				pSubButton->SetStyle(Style & ~TBBS_DISABLED);
+			else
+				pSubButton->SetStyle(Style | TBBS_DISABLED);
+			break;
+
+		case ID_PIECE_DETACH:
+			if (flags & LC_SEL_UNSELECTED)
+				pSubButton->SetStyle(Style & ~TBBS_DISABLED);
+			else
+				pSubButton->SetStyle(Style | TBBS_DISABLED);
+			break;
+
+		case ID_PIECE_EDITGROUPS:
+			if (flags & LC_SEL_NO_PIECES)
+				pSubButton->SetStyle(Style | TBBS_DISABLED);
+			else
+				pSubButton->SetStyle(Style & ~TBBS_DISABLED);
+			break;
+		}
 	}
-	pMenu->EnableMenuItem(ID_EDIT_SELECTNONE, MF_BYCOMMAND | 
-		(flags & (LC_SEL_PIECE|LC_SEL_CAMERA|LC_SEL_LIGHT) ? MF_ENABLED : (MF_DISABLED | MF_GRAYED)));
-	pMenu->EnableMenuItem(ID_EDIT_SELECTALL, MF_BYCOMMAND | 
-		(flags & LC_SEL_UNSELECTED ? MF_ENABLED : (MF_DISABLED | MF_GRAYED)));
 
-	// cut, copy
-	pMenu->EnableMenuItem(ID_EDIT_CUT, MF_BYCOMMAND | 
-		(flags & (LC_SEL_PIECE|LC_SEL_CAMERA|LC_SEL_LIGHT) ? MF_ENABLED : (MF_DISABLED | MF_GRAYED)));
-	pMenu->EnableMenuItem(ID_EDIT_COPY, MF_BYCOMMAND | 
-		(flags & (LC_SEL_PIECE|LC_SEL_CAMERA|LC_SEL_LIGHT) ? MF_ENABLED : (MF_DISABLED | MF_GRAYED)));
-	pCtrl->EnableButton(ID_EDIT_CUT, flags & (LC_SEL_PIECE|LC_SEL_CAMERA|LC_SEL_LIGHT) ? TRUE : FALSE);
-	pCtrl->EnableButton(ID_EDIT_COPY, flags & (LC_SEL_PIECE|LC_SEL_CAMERA|LC_SEL_LIGHT) ? TRUE : FALSE);
-
-	// mirror/array, hide sel/unsel, unhideall
-	pBar = (CToolBar*)pFrame->GetControlBar(ID_VIEW_TOOLS_BAR);
-	pCtrl = &pBar->GetToolBarCtrl();
-	pCtrl->EnableButton(ID_PIECE_ARRAY, flags & LC_SEL_PIECE ? TRUE : FALSE);
-	pCtrl->EnableButton(ID_PIECE_MIRROR, flags & LC_SEL_PIECE ? TRUE : FALSE);
-	pMenu = GetMainMenu(3);
-	pMenu->EnableMenuItem(ID_PIECE_DELETE, MF_BYCOMMAND | 
-		(flags & (LC_SEL_PIECE|LC_SEL_CAMERA|LC_SEL_LIGHT) ? MF_ENABLED : (MF_DISABLED | MF_GRAYED)));
-	pMenu->EnableMenuItem(ID_PIECE_COPYKEYS, MF_BYCOMMAND | 
-		(flags & (LC_SEL_PIECE|LC_SEL_CAMERA|LC_SEL_LIGHT) ? MF_ENABLED : (MF_DISABLED | MF_GRAYED)));
-	pMenu->EnableMenuItem(ID_PIECE_ARRAY, MF_BYCOMMAND | 
-		(flags & LC_SEL_PIECE ? MF_ENABLED : (MF_DISABLED | MF_GRAYED)));
-	pMenu->EnableMenuItem(ID_PIECE_MIRROR, MF_BYCOMMAND | 
-		(flags & LC_SEL_PIECE ? MF_ENABLED : (MF_DISABLED | MF_GRAYED)));
-	pMenu->EnableMenuItem(ID_PIECE_UNHIDEALL, MF_BYCOMMAND | 
-		(flags & LC_SEL_HIDDEN ? MF_ENABLED : (MF_DISABLED | MF_GRAYED)));
-	pMenu->EnableMenuItem(ID_PIECE_HIDESELECTED, MF_BYCOMMAND | 
-		(flags & LC_SEL_PIECE ? MF_ENABLED : (MF_DISABLED | MF_GRAYED)));
-	pMenu->EnableMenuItem(ID_PIECE_HIDEUNSELECTED, MF_BYCOMMAND | 
-		(flags & LC_SEL_UNSELECTED ? MF_ENABLED : (MF_DISABLED | MF_GRAYED)));
-
-	// group
-	pMenu->EnableMenuItem(ID_PIECE_GROUP, MF_BYCOMMAND | 
-		(flags & LC_SEL_CANGROUP ? MF_ENABLED : (MF_DISABLED | MF_GRAYED)));
-	pMenu->EnableMenuItem(ID_PIECE_UNGROUP, MF_BYCOMMAND | 
-		(flags & LC_SEL_GROUP ? MF_ENABLED : (MF_DISABLED | MF_GRAYED)));
-	pMenu->EnableMenuItem(ID_PIECE_ATTACH, MF_BYCOMMAND | 
-		((flags & (LC_SEL_GROUP|LC_SEL_FOCUSGROUP)) == (LC_SEL_GROUP) ? MF_ENABLED : (MF_DISABLED | MF_GRAYED)));
-	pMenu->EnableMenuItem(ID_PIECE_DETACH, MF_BYCOMMAND | 
-		(flags & LC_SEL_FOCUSGROUP ? MF_ENABLED : (MF_DISABLED | MF_GRAYED)));
-	pMenu->EnableMenuItem(ID_PIECE_EDITGROUPS, MF_BYCOMMAND | 
-		((flags & LC_SEL_NO_PIECES) == 0 ? MF_ENABLED : (MF_DISABLED | MF_GRAYED)));
-
-	pCtrl->EnableButton(ID_PIECE_PREVIOUS, flags & LC_SEL_PIECE ? TRUE : FALSE);
-	pCtrl->EnableButton(ID_PIECE_NEXT, flags & LC_SEL_PIECE ? TRUE : FALSE);
+	EnableToolBarButton(pFrame->m_wndToolsBar, ID_PIECE_PREVIOUS, flags & LC_SEL_PIECE ? TRUE : FALSE); // FIXME: disable if current step is 1
+	EnableToolBarButton(pFrame->m_wndToolsBar, ID_PIECE_NEXT, flags & LC_SEL_PIECE ? TRUE : FALSE);
 
 	// Status bar text.
 	if (SelectedCount == 0)
@@ -689,40 +692,18 @@ void SystemUpdateSelected(unsigned long flags, int SelectedCount, Object* Focus)
 // Changed current step/frame
 void SystemUpdateTime(bool bAnimation, int nTime, int nTotal)
 {
-	// Toolbar
-	CFrameWnd* pFrame = (CFrameWnd*)AfxGetMainWnd();
+	CMainFrame* pFrame = (CMainFrame*)AfxGetMainWnd();
 	if (!pFrame)
 		return;
-	CToolBar* pBar = (CToolBar*)pFrame->GetControlBar(ID_VIEW_ANIMATION_BAR);
-	CToolBarCtrl* pCtrl = &pBar->GetToolBarCtrl();
-
-	pCtrl->EnableButton(ID_VIEW_STEP_NEXT, nTime < nTotal ? TRUE : FALSE);
-	pCtrl->EnableButton(ID_VIEW_STEP_PREVIOUS, nTime > 1 ? TRUE : FALSE);
-	pCtrl->EnableButton(ID_VIEW_STEP_FIRST, nTime != 1 ? TRUE : FALSE);
-	pCtrl->EnableButton(ID_VIEW_STEP_LAST, nTime != nTotal ? TRUE : FALSE);
-
-	// Main menu
-	CBMPMenu* pMainMenu = (CBMPMenu*)GetMainMenu(2)->GetSubMenu(14);
-
-	pMainMenu->EnableMenuItem(ID_VIEW_STEP_NEXT, MF_BYCOMMAND | 
-		(nTime < nTotal ? MF_ENABLED : (MF_DISABLED | MF_GRAYED)));
-	pMainMenu->EnableMenuItem(ID_VIEW_STEP_PREVIOUS, MF_BYCOMMAND | 
-		(nTime > 1 ? MF_ENABLED : (MF_DISABLED | MF_GRAYED)));
-	pMainMenu->EnableMenuItem(ID_VIEW_STEP_FIRST, MF_BYCOMMAND | 
-		(nTime != 1 ? MF_ENABLED : (MF_DISABLED | MF_GRAYED)));
-	pMainMenu->EnableMenuItem(ID_VIEW_STEP_LAST, MF_BYCOMMAND | 
-		(nTime != nTotal ? MF_ENABLED : (MF_DISABLED | MF_GRAYED)));
 
 	// Status bar
 	char szStep[11];
-	CStatusBar* pStatusBar = (CStatusBar*)pFrame->GetControlBar(AFX_IDW_STATUS_BAR);
-
 	if (bAnimation)
 		sprintf(szStep, "%i/%i", nTime, nTotal);
 	else
 		sprintf(szStep, " Step %i ", nTime);
 
-	pStatusBar->SetPaneText(pStatusBar->CommandToIndex(ID_INDICATOR_STEP), LPCSTR(szStep));
+	pFrame->m_wndStatusBar.SetPaneText(pFrame->m_wndStatusBar.CommandToIndex(ID_INDICATOR_STEP), LPCSTR(szStep));
 
 	// Choose step dialog
 	if (StepModeless != NULL)
@@ -743,45 +724,63 @@ void SystemUpdateSnap(unsigned short MoveSnap, unsigned short RotateSnap)
 
 void SystemUpdatePaste(bool enable)
 {
-	CMenu* pMenu = GetMainMenu(1);
-	CFrameWnd* pFrame = (CFrameWnd*)AfxGetMainWnd();
-	CToolBar* pBar = (CToolBar*)pFrame->GetControlBar(AFX_IDW_TOOLBAR);
-	CToolBarCtrl* pCtrl = &pBar->GetToolBarCtrl();
+	CMainFrame* pFrame = (CMainFrame*)AfxGetMainWnd();
+	if (!pFrame)
+		return;
 
-	if (pMenu != NULL)
-		pMenu->EnableMenuItem(ID_EDIT_PASTE, MF_BYCOMMAND | (enable ? MF_ENABLED : (MF_DISABLED | MF_GRAYED)));
+	CMFCMenuBar& MenuBar = pFrame->m_wndMenuBar;
+	CMFCToolBarButton* pEditButton = MenuBar.GetButton(1);
+	CMFCToolBarMenuButton* pEditMenuButton = DYNAMIC_DOWNCAST(CMFCToolBarMenuButton, pEditButton);
 
-	if (pCtrl)
-		pCtrl->EnableButton(ID_EDIT_PASTE, enable ? TRUE : FALSE);
+	const CObList& editCommands = pEditMenuButton->GetCommands();
+
+	for (POSITION pos = editCommands.GetHeadPosition (); pos != NULL;)
+	{
+		CMFCToolBarButton* pSubButton = (CMFCToolBarButton*)editCommands.GetNext(pos);
+		ASSERT_VALID(pSubButton);
+
+		UINT Style = pSubButton->m_nStyle;
+
+		switch (pSubButton->m_nID)
+		{
+		case ID_EDIT_PASTE:
+			if (enable)
+				pSubButton->SetStyle(Style & ~TBBS_DISABLED);
+			else
+				pSubButton->SetStyle(Style | TBBS_DISABLED);
+			break;
+		}
+	}
+
+	EnableToolBarButton(pFrame->m_wndStandardBar, ID_EDIT_PASTE, enable ? TRUE : FALSE);
 }
 
 void SystemUpdatePlay(bool play, bool stop)
 {
-	CFrameWnd* pFrame = (CFrameWnd*)AfxGetMainWnd();
-	CToolBar* pBar = (CToolBar*)pFrame->GetControlBar(ID_VIEW_ANIMATION_BAR);
-	CToolBarCtrl* pCtrl = &pBar->GetToolBarCtrl();
+	CMainFrame* pFrame = (CMainFrame*)AfxGetMainWnd();
 
-	pCtrl->EnableButton(ID_ANIMATOR_PLAY, play ? TRUE : FALSE);
-	pCtrl->EnableButton(ID_ANIMATOR_STOP, stop ? TRUE : FALSE);
+	EnableToolBarButton(pFrame->m_wndAnimationBar, ID_ANIMATOR_PLAY, play ? TRUE : FALSE);
+	EnableToolBarButton(pFrame->m_wndAnimationBar, ID_ANIMATOR_STOP, stop ? TRUE : FALSE);
 }
 
 void SystemUpdateAnimation(bool bAnimation, bool bAddKeys)
 {
 	// Toolbar
-	CFrameWnd* pFrame = (CFrameWnd*)AfxGetMainWnd();
+	CMainFrame* pFrame = (CMainFrame*)AfxGetMainWnd();
 	if (!pFrame)
 		return;
-	CToolBar* pBar = (CToolBar*)pFrame->GetControlBar(ID_VIEW_ANIMATION_BAR);
-	CToolBarCtrl* pCtrl = &pBar->GetToolBarCtrl();
 
-	pCtrl->CheckButton(ID_ANIMATOR_TOGGLE, bAnimation ? TRUE : FALSE);
-	pCtrl->CheckButton(ID_ANIMATOR_KEY, bAddKeys ? TRUE : FALSE);
-	pCtrl->EnableButton(ID_ANIMATOR_PLAY, bAnimation ? TRUE : FALSE);
-	pCtrl->EnableButton(ID_ANIMATOR_STOP, FALSE);
+	CheckToolBarButton(pFrame->m_wndAnimationBar, ID_ANIMATOR_TOGGLE, bAnimation ? TRUE : FALSE);
+	CheckToolBarButton(pFrame->m_wndAnimationBar, ID_ANIMATOR_KEY, bAddKeys ? TRUE : FALSE);
+	EnableToolBarButton(pFrame->m_wndAnimationBar, ID_ANIMATOR_PLAY, bAnimation ? TRUE : FALSE);
+	EnableToolBarButton(pFrame->m_wndAnimationBar, ID_ANIMATOR_STOP, FALSE);
 
 	// Menu
 	char* txt;
 	CMenu* pMenu = GetMainMenu(3);
+	if (!pMenu)
+		return;
+
 	UINT nState = pMenu->GetMenuState(ID_PIECE_COPYKEYS, MF_BYCOMMAND);
 	nState &= ~(MF_BITMAP|MF_OWNERDRAW|MF_SEPARATOR);
 
@@ -790,319 +789,38 @@ void SystemUpdateAnimation(bool bAnimation, bool bAddKeys)
 	else
 		txt = "Copy Keys from Animation";
 	
-	pMenu->ModifyMenu(ID_PIECE_COPYKEYS, MF_BYCOMMAND |
-        MF_STRING | nState, ID_PIECE_COPYKEYS, txt);
+	pMenu->ModifyMenu(ID_PIECE_COPYKEYS, MF_BYCOMMAND | MF_STRING | nState, ID_PIECE_COPYKEYS, txt);
 }
 
 void SystemUpdateCurrentCamera(Camera* pOld, Camera* pNew, Camera* pCamera)
 {
-	CMenu* Menu = GetMainMenu(2);
-	if (!Menu)
-		return;
-	CBMPMenu* pMainMenu = (CBMPMenu*)Menu->GetSubMenu(13);
-	CMenu* pPopupMenu = menuPopups.GetSubMenu(1)->GetSubMenu(3);
-	int i;
-
-	for (i = 0; pCamera; i++, pCamera = pCamera->m_pNext)
-	{
-		if (pOld == pCamera)
-		{
-			pPopupMenu->CheckMenuItem(i + ID_CAMERA_FIRST, MF_BYCOMMAND | MF_UNCHECKED);
-			pMainMenu->CheckMenuItem(i + ID_CAMERA_FIRST, MF_BYCOMMAND | MF_UNCHECKED);
-		}
-
-		if (pNew == pCamera)
-		{
-			pPopupMenu->CheckMenuItem(i + ID_CAMERA_FIRST, MF_BYCOMMAND | MF_CHECKED);
-			pMainMenu->CheckMenuItem(i + ID_CAMERA_FIRST, MF_BYCOMMAND | MF_CHECKED);
-			SetMenuItemBitmaps(pPopupMenu->m_hMenu, i + ID_CAMERA_FIRST, MF_BYCOMMAND, NULL, hbmMenuDot);
-			SetMenuItemBitmaps(pMainMenu->m_hMenu, i + ID_CAMERA_FIRST, MF_BYCOMMAND, NULL, hbmMenuDot);
-		}
-	}
 }
 
-// Update the list of cameras
 void SystemUpdateCameraMenu(Camera* pCamera)
 {
-	CMenu* Menu = GetMainMenu(2);
-	if (!Menu)
-		return;
-	CBMPMenu* pMainMenu = (CBMPMenu*)Menu->GetSubMenu(13);
-	CMenu* pPopupMenu = menuPopups.GetSubMenu(1)->GetSubMenu(3);
-	Camera* pFirst = pCamera;
-	int i;
-
-	while (pMainMenu->GetMenuItemCount())
-		pMainMenu->DeleteMenu(0, MF_BYPOSITION);
-	while (pPopupMenu->GetMenuItemCount())
-		pPopupMenu->DeleteMenu(0, MF_BYPOSITION);
-
-	for (i = 0; pCamera; i++, pCamera = pCamera->m_pNext)
-		if (i > 6)
-		{
-			pMainMenu->AppendODMenu(pCamera->GetName(), MF_ENABLED, i + ID_CAMERA_FIRST);
-			pPopupMenu->AppendMenu(MF_STRING, i + ID_CAMERA_FIRST, pCamera->GetName());
-		}
-
-	if (i > 7)
-	{
-		pMainMenu->AppendODMenu("", MF_SEPARATOR);
-		pPopupMenu->AppendMenu(MF_SEPARATOR);
-	}
-
-	pCamera = pFirst;
-	for (i = 0; pCamera && (i < 7); i++, pCamera = pCamera->m_pNext)
-	{
-		pMainMenu->AppendODMenu(pCamera->GetName(), MF_ENABLED, i + ID_CAMERA_FIRST);
-		pPopupMenu->AppendMenu(MF_STRING, i + ID_CAMERA_FIRST, pCamera->GetName());
-
-		pMainMenu->ChangeMenuItemShortcut("str", i + ID_CAMERA_FIRST);
-	}
-
-	pMainMenu->AppendODMenu("", MF_SEPARATOR);
-	pPopupMenu->AppendMenu(MF_SEPARATOR);
-	pMainMenu->AppendODMenu("Reset", MF_ENABLED, ID_VIEW_CAMERAS_RESET);
-	pPopupMenu->AppendMenu(MF_STRING, ID_VIEW_CAMERAS_RESET, "Reset");
-//	pMainMenu->AppendODMenu("Adjust...\t", MF_ENABLED, ID_VIEW_VIEWPOINT);
-//	pPopupMenu->AppendODMenu("Adjust...\t", MF_ENABLED, ID_VIEW_VIEWPOINT);
-
-  ((CMainFrame*)AfxGetMainWnd())->UpdateMenuAccelerators(); 
 }
 
 void SystemUpdateCategories(bool SearchOnly)
 {
-	CFrameWnd* pFrame = (CFrameWnd*)AfxGetMainWnd();
+	CMainFrame* pFrame = (CMainFrame*)AfxGetMainWnd();
 
 	if (!pFrame)
 		return;
 
-	CPiecesBar* pBar = (CPiecesBar*)pFrame->GetControlBar(ID_VIEW_PIECES_BAR);
-	pBar->UpdatePiecesTree(SearchOnly);
+	pFrame->m_wndPiecesBar.UpdatePiecesTree(SearchOnly);
 }
 
-extern UINT AFXAPI AfxGetFileTitle(LPCTSTR lpszPathName, LPTSTR lpszTitle, UINT nMax);
-extern UINT AFXAPI AfxGetFileName(LPCTSTR lpszPathName, LPTSTR lpszTitle, UINT nMax);
-
-/////////////////////////////////////////////////////////////////////////////
-// lpszCanon = C:\MYAPP\DEBUGS\C\TESWIN.C
-//
-// cchMax   b   Result
-// ------   -   ---------
-//  1- 7    F   <empty>
-//  1- 7    T   TESWIN.C
-//  8-14    x   TESWIN.C
-// 15-16    x   C:\...\TESWIN.C
-// 17-23    x   C:\...\C\TESWIN.C
-// 24-25    x   C:\...\DEBUGS\C\TESWIN.C
-// 26+      x   C:\MYAPP\DEBUGS\C\TESWIN.C
-
-#ifndef _MAC
-static void AbbreviateName(LPTSTR lpszCanon, int cchMax, BOOL bAtLeastName)
+void SystemUpdateRecentMenu(char names[4][MAX_PATH])
 {
-	int cchFullPath, cchFileName, cchVolName;
-	const TCHAR* lpszCur;
-	const TCHAR* lpszBase;
-	const TCHAR* lpszFileName;
-
-	lpszBase = lpszCanon;
-	cchFullPath = lstrlen(lpszCanon);
-
-	cchFileName = AfxGetFileName(lpszCanon, NULL, 0) - 1;
-	lpszFileName = lpszBase + (cchFullPath-cchFileName);
-
-	// If cchMax is more than enough to hold the full path name, we're done.
-	// This is probably a pretty common case, so we'll put it first.
-	if (cchMax >= cchFullPath)
-		return;
-
-	// If cchMax isn't enough to hold at least the basename, we're done
-	if (cchMax < cchFileName)
-	{
-		lstrcpy(lpszCanon, (bAtLeastName) ? lpszFileName : _T(""));
-		return;
-	}
-
-	// Calculate the length of the volume name.  Normally, this is two characters
-	// (e.g., "C:", "D:", etc.), but for a UNC name, it could be more (e.g.,
-	// "\\server\share").
-	//
-	// If cchMax isn't enough to hold at least <volume_name>\...\<base_name>, the
-	// result is the base filename.
-
-	lpszCur = lpszBase + 2;                 // Skip "C:" or leading "\\"
-
-	if (lpszBase[0] == '\\' && lpszBase[1] == '\\') // UNC pathname
-	{
-		// First skip to the '\' between the server name and the share name,
-		while (*lpszCur != '\\')
-		{
-			lpszCur = _tcsinc(lpszCur);
-			ASSERT(*lpszCur != '\0');
-		}
-	}
-	// if a UNC get the share name, if a drive get at least one directory
-	ASSERT(*lpszCur == '\\');
-	// make sure there is another directory, not just c:\filename.ext
-	if (cchFullPath - cchFileName > 3)
-	{
-		lpszCur = _tcsinc(lpszCur);
-		while (*lpszCur != '\\')
-		{
-			lpszCur = _tcsinc(lpszCur);
-			ASSERT(*lpszCur != '\0');
-		}
-	}
-	ASSERT(*lpszCur == '\\');
-
-	cchVolName = lpszCur - lpszBase;
-	if (cchMax < cchVolName + 5 + cchFileName)
-	{
-		lstrcpy(lpszCanon, lpszFileName);
-		return;
-	}
-
-	// Now loop through the remaining directory components until something
-	// of the form <volume_name>\...\<one_or_more_dirs>\<base_name> fits.
-	//
-	// Assert that the whole filename doesn't fit -- this should have been
-	// handled earlier.
-
-	ASSERT(cchVolName + (int)lstrlen(lpszCur) > cchMax);
-	while (cchVolName + 4 + (int)lstrlen(lpszCur) > cchMax)
-	{
-		do
-		{
-			lpszCur = _tcsinc(lpszCur);
-			ASSERT(*lpszCur != '\0');
-		}
-		while (*lpszCur != '\\');
-	}
-
-	// Form the resultant string and we're done.
-	lpszCanon[cchVolName] = '\0';
-	lstrcat(lpszCanon, _T("\\..."));
-	lstrcat(lpszCanon, lpszCur);
-}
-#endif
-
-static BOOL GetDisplayName(char* filename, CString& strName, LPCTSTR lpszCurDir, int nCurDir, BOOL bAtLeastName)
-{
-	LPTSTR lpch = strName.GetBuffer(_MAX_PATH);
-#ifndef _MAC
-	lstrcpy(lpch, filename);
-	// nLenDir is the length of the directory part of the full path
-	int nLenDir = lstrlen(lpch) - (AfxGetFileName(lpch, NULL, 0) - 1);
-	BOOL bSameDir = FALSE;
-	if (nLenDir == nCurDir)
-	{
-		TCHAR chSave = lpch[nLenDir];
-		lpch[nCurDir] = 0;  // terminate at same location as current dir
-		bSameDir = lstrcmpi(lpszCurDir, lpch) == 0;
-		lpch[nLenDir] = chSave;
-	}
-	// copy the full path, otherwise abbreviate the name
-	if (bSameDir)
-	{
-		// copy file name only since directories are same
-		char szTemp[_MAX_PATH];
-		AfxGetFileTitle(lpch+nCurDir, szTemp, sizeof(szTemp));
-		lstrcpyn(lpch, szTemp, _MAX_PATH);
-	}
-	else
-	{
-		// strip the extension if the system calls for it
-		char szTemp[_MAX_PATH];
-		AfxGetFileTitle(lpch+nLenDir, szTemp, sizeof(szTemp));
-		lstrcpyn(lpch+nLenDir, szTemp, _MAX_PATH-nLenDir);
-
-		// abbreviate name based on what will fit in limited space
-		AbbreviateName(lpch, 30, bAtLeastName);
-	}
-#else
-	// for Mac just show the file title name without path
-	AfxGetFileTitle(filename, lpch, _MAX_PATH);
-#endif
-	strName.ReleaseBuffer();
-	return TRUE;
-}
-
-void SystemUpdateRecentMenu(char names[4][LC_MAXPATH])
-{
-	CBMPMenu* pMenu = (CBMPMenu*)GetMainMenu(0);
-	if (!pMenu)
-		return;
-	UINT nState;
-
-	pMenu->DeleteMenu(ID_FILE_MRU_FILE2, MF_BYCOMMAND);
-	pMenu->DeleteMenu(ID_FILE_MRU_FILE3, MF_BYCOMMAND);
-	pMenu->DeleteMenu(ID_FILE_MRU_FILE4, MF_BYCOMMAND);
-
-	if (strlen(names[0]) == 0)
-	{
-		nState = pMenu->GetMenuState(ID_FILE_MRU_FILE1, MF_BYCOMMAND);
-		nState &= ~(MF_BITMAP|MF_OWNERDRAW|MF_SEPARATOR);
-		pMenu->ModifyMenu(ID_FILE_MRU_FILE1, MF_BYCOMMAND |
-		    MF_STRING | nState, ID_FILE_MRU_FILE1, "Recent File");
-		pMenu->EnableMenuItem(ID_FILE_MRU_FILE1, MF_BYCOMMAND | MF_DISABLED | MF_GRAYED);
-		return;
-	}
-
-#ifndef _MAC
-	TCHAR szCurDir[_MAX_PATH];
-	GetCurrentDirectory(_MAX_PATH, szCurDir);
-	int nCurDir = lstrlen(szCurDir);
-	ASSERT(nCurDir >= 0);
-	szCurDir[nCurDir] = '\\';
-	szCurDir[++nCurDir] = '\0';
-#endif
-
-	CString strName;
-	CString strTemp;
-	for (int i = 0; i < 4; i++)
-	{
-		if (strlen(names[i]) == 0)
-			break;
-		if (!GetDisplayName(names[i], strName, szCurDir, nCurDir, TRUE))
-			break;
-
-		// double up any '&' characters so they are not underlined
-		LPCTSTR lpszSrc = strName;
-		LPTSTR lpszDest = strTemp.GetBuffer(strName.GetLength()*2);
-		while (*lpszSrc != 0)
-		{
-			if (*lpszSrc == '&')
-				*lpszDest++ = '&';
-			if (_istlead(*lpszSrc))
-				*lpszDest++ = *lpszSrc++;
-			*lpszDest++ = *lpszSrc++;
-		}
-		*lpszDest = 0;
-		strTemp.ReleaseBuffer();
-
-		// insert mnemonic + the file name
-		char buf[200];
-		sprintf(buf, "&%d %s", i+1, strTemp);
-
-		if (i != 0)
-		{
-			UINT x = pMenu->GetMenuItemCount() - 2;
-			pMenu->InsertMenu(x, MF_BYPOSITION|MF_STRING, ID_FILE_MRU_FILE1 + i, buf);
-		}
-		else
-		{
-			nState = pMenu->GetMenuState(ID_FILE_MRU_FILE1, MF_BYCOMMAND);
-			nState &= ~(MF_BITMAP|MF_OWNERDRAW|MF_SEPARATOR);
-			pMenu->ModifyMenu(ID_FILE_MRU_FILE1, MF_BYCOMMAND |
-			    MF_STRING | nState, ID_FILE_MRU_FILE1 + i, buf);
-			pMenu->EnableMenuItem(ID_FILE_MRU_FILE1, MF_BYCOMMAND | MF_ENABLED);
-		}
-	}
+	theApp.UpdateMRU(names);
 }
 
 // if x = -1, get cursor pos 
 void SystemDoPopupMenu(int nMenu, int x, int y)
 {
-	CMenu* pPopup;
+	CMenu PopupMenus;
+	PopupMenus.LoadMenu(IDR_POPUPS);
+
 	POINT pt;
 
 	if (x != -1)
@@ -1113,8 +831,8 @@ void SystemDoPopupMenu(int nMenu, int x, int y)
 	else
 		GetCursorPos(&pt);
 
-	pPopup = menuPopups.GetSubMenu(nMenu);
-	pPopup->TrackPopupMenu(TPM_LEFTALIGN | TPM_LEFTBUTTON, pt.x, pt.y, AfxGetMainWnd());
+	CMFCPopupMenu* Popup = new CMFCPopupMenu();
+	Popup->Create(AfxGetMainWnd(), pt.x, pt.y, PopupMenus.GetSubMenu(nMenu)->Detach());
 }
 
 // Private MFC function only sets the title if it's different
@@ -1128,7 +846,7 @@ void SystemSetWindowCaption(char* caption)
 	AfxSetWindowText(AfxGetMainWnd()->m_hWnd, caption);
 }
 
-int SystemDoMessageBox(char* prompt, int nMode)
+int SystemDoMessageBox(const char* prompt, int nMode)
 {
 	return AfxMessageBox(prompt, nMode);
 }
@@ -1384,6 +1102,47 @@ bool SystemDoDialog(int nMode, void* param)
 			}
 		} break;
 
+		case LC_DLG_DIRECTORY_BROWSE:
+		{
+			LC_DLG_DIRECTORY_BROWSE_OPTS* Opts = (LC_DLG_DIRECTORY_BROWSE_OPTS*)param;
+
+			strcpy(Opts->Path, "");
+
+			LPMALLOC ShellMalloc;
+			if (SHGetMalloc(&ShellMalloc) == NOERROR)
+			{
+				BROWSEINFO bi;
+				LPITEMIDLIST pidl;
+		
+				if (AfxGetMainWnd())
+					bi.hwndOwner = AfxGetMainWnd()->GetSafeHwnd();
+				else
+					bi.hwndOwner = ::GetDesktopWindow();
+				bi.pidlRoot = NULL;
+				bi.pszDisplayName = Opts->Path;
+				bi.lpszTitle = Opts->Title;
+				bi.ulFlags = BIF_RETURNFSANCESTORS | BIF_RETURNONLYFSDIRS;
+				bi.lpfn = NULL;
+				bi.lParam = 0;
+		
+				pidl = SHBrowseForFolder(&bi);
+				if (pidl != NULL)
+				{
+					if (SHGetPathFromIDList(pidl, Opts->Path))
+					{ 
+						if (Opts->Path[strlen(Opts->Path)-1] != '\\') 
+							strcat(Opts->Path, "\\");
+						return true;
+					}
+					ShellMalloc->Free(pidl);
+				}
+				ShellMalloc->Release();
+			}
+
+			return false;
+
+		} break;
+
 		case LC_DLG_HTML:
 		{
 			LC_HTMLDLG_OPTS* opts = (LC_HTMLDLG_OPTS*)param;
@@ -1538,8 +1297,8 @@ bool SystemDoDialog(int nMode, void* param)
 			CLibraryDlg dlg;
 			dlg.DoModal();
 
-			CPiecesBar* pBar = (CPiecesBar*)((CFrameWnd*)AfxGetMainWnd())->GetControlBar(ID_VIEW_PIECES_BAR);
-			pBar->UpdatePiecesTree(false);
+			CMainFrame* pFrame = (CMainFrame*)AfxGetMainWnd();
+			pFrame->m_wndPiecesBar.UpdatePiecesTree(false);
 
 			return true;
 		} break;
@@ -1555,7 +1314,7 @@ bool SystemDoDialog(int nMode, void* param)
 		{
 			if (StepModeless == NULL)
 			{
-				CFrameWnd* pFrame = (CFrameWnd*)AfxGetMainWnd();
+				CMainFrame* pFrame = (CMainFrame*)AfxGetMainWnd();
 				CView* pView = pFrame->GetActiveView();
 				StepModeless = new CStepDlg(&StepModeless, pView);
 				StepModeless->Create(IDD_STEP, pView);
@@ -1643,7 +1402,7 @@ typedef struct
 void* Sys_StartMemoryRender(int width, int height)
 {
 	LC_RENDER* render = (LC_RENDER*)malloc(sizeof(LC_RENDER));
-	CFrameWnd* pFrame = (CFrameWnd*)AfxGetMainWnd();
+	CMainFrame* pFrame = (CMainFrame*)AfxGetMainWnd();
 	CView* pView = pFrame->GetActiveView();
 	CDC* pDC = pView->GetDC();
 	render->oldhdc = pfnwglGetCurrentDC();
@@ -1706,7 +1465,7 @@ void SystemPieceComboAdd(char* name)
 
 void SystemCaptureMouse()
 {
-	CFrameWnd* pFrame = (CFrameWnd*)AfxGetMainWnd();
+	CMainFrame* pFrame = (CMainFrame*)AfxGetMainWnd();
 	CView* pView = pFrame->GetActiveView();
 	pView->SetCapture();
 }
@@ -1763,17 +1522,53 @@ File* SystemImportClipboard()
 	return clip;
 }
 
-bool Sys_KeyDown (int key)
+bool Sys_KeyDown(int key)
 {
-  return GetKeyState (KEY_CONTROL) < 0;
+	return GetKeyState(key) < 0;
 }
 
+void Sys_GetFileList(const char* Path, ObjArray<String>& FileList)
+{
+	FileList.RemoveAll();
+
+	WIN32_FIND_DATA FindData;
+	HANDLE Find = INVALID_HANDLE_VALUE;
+	char Dir[MAX_PATH], FindPath[MAX_PATH];
+
+	strcpy(Dir, Path);
+	int Len = strlen(Dir);
+
+	if (Dir[Len-1] != '\\' && Dir[Len-1] != '/')
+		strcat(Dir, "\\");
+
+	strcpy(FindPath, Dir);
+	strcat(FindPath, "*.dat");
+
+	Find = FindFirstFile(FindPath, &FindData);
+
+	if (Find == INVALID_HANDLE_VALUE) 
+		return;
+
+	do
+	{
+		if (FindData.dwFileAttributes & FILE_ATTRIBUTE_DIRECTORY)
+			continue;
+
+		char File[MAX_PATH];
+		strcpy(File, Dir);
+		strcat(File, FindData.cFileName);
+		FileList.Add(File);
+	}
+	while (FindNextFile(Find, &FindData) != 0);
+
+	FindClose(Find);
+}
 
 void SystemPumpMessages()
 {
 	MSG msg;
 
-  while(PeekMessage(&msg, NULL, 0, 0, PM_REMOVE))
+	while(PeekMessage(&msg, NULL, 0, 0, PM_REMOVE))
 	{
 		TranslateMessage(&msg);
 		DispatchMessage(&msg);
@@ -1787,39 +1582,37 @@ long SystemGetTicks()
 
 void SystemStartProgressBar(int nLower, int nUpper, int nStep, const char* Text)
 {
-	CFrameWnd* pFrame = (CFrameWnd*)AfxGetMainWnd();
+	CMainFrame* pFrame = (CMainFrame*)AfxGetMainWnd();
 	if (!pFrame)
 		return;
-	CCADStatusBar* pStatusBar = (CCADStatusBar*)pFrame->GetControlBar(AFX_IDW_STATUS_BAR);
+	CCADStatusBar* pStatusBar = &pFrame->m_wndStatusBar;
 
 	pStatusBar->ShowProgressBar(TRUE);
 	pStatusBar->SetProgressBarRange(nLower, nUpper);
 	pStatusBar->SetProgressBarStep(nStep);
 	pStatusBar->SetProgressBarPos(0);
 
-  ((CMainFrame*)AfxGetMainWnd())->SetStatusBarMessage(Text); 
-	((CMainFrame*)AfxGetMainWnd())->SetMessageText(Text);
+	pFrame->SetStatusBarMessage(Text); 
+	pFrame->SetMessageText(Text);
 }
 
 void SytemEndProgressBar()
 {
-	CFrameWnd* pFrame = (CFrameWnd*)AfxGetMainWnd();
+	CMainFrame* pFrame = (CMainFrame*)AfxGetMainWnd();
 	if (!pFrame)
 		return;
-	CCADStatusBar* pStatusBar = (CCADStatusBar*)pFrame->GetControlBar(AFX_IDW_STATUS_BAR);
 
-	pStatusBar->ShowProgressBar(FALSE);
+	pFrame->m_wndStatusBar.ShowProgressBar(FALSE);
 
-  ((CMainFrame*)AfxGetMainWnd())->SetStatusBarMessage(""); 
-	((CMainFrame*)AfxGetMainWnd())->SetMessageText(AFX_IDS_IDLEMESSAGE);
+	pFrame->SetStatusBarMessage(""); 
+	pFrame->SetMessageText(AFX_IDS_IDLEMESSAGE);
 }
 
 void SytemStepProgressBar()
 {
-	CFrameWnd* pFrame = (CFrameWnd*)AfxGetMainWnd();
+	CMainFrame* pFrame = (CMainFrame*)AfxGetMainWnd();
 	if (!pFrame)
 		return;
-	CCADStatusBar* pStatusBar = (CCADStatusBar*)pFrame->GetControlBar(AFX_IDW_STATUS_BAR);
 
-	pStatusBar->StepProgressBar();
+	pFrame->m_wndStatusBar.StepProgressBar();
 }
