@@ -8,6 +8,20 @@
 #include "lc_application.h"
 #include <math.h>
 #include <shlobj.h>
+#include "config.h"
+
+#ifdef LC_HAVE_3DSFTK
+#pragma comment(lib, "3dsftk")
+#endif
+
+#ifdef LC_HAVE_JPEGLIB
+#pragma comment(lib, "jpeglib")
+#endif
+
+#ifdef LC_HAVE_PNGLIB
+#pragma comment(lib, "libpng")
+#pragma comment(lib, "zlib")
+#endif
 
 // Create a bitmap of a given size and color
 HBITMAP CreateColorBitmap (UINT cx, UINT cy, COLORREF cr)
@@ -242,6 +256,8 @@ BOOL FolderBrowse(CString *strFolder, LPCSTR lpszTitle, HWND hWndOwner)
 	return FALSE;
 } 
 
+#ifdef LC_HAVE_3DSFTK
+
 #include "3dsftk\inc\3dsftk.h"
 #include "globals.h"
 #include "project.h"
@@ -423,6 +439,7 @@ void Export3DStudio()
 		matr->wiresize = 1.0f;
 		matr->shading = Phong;
 		matr->useblur = False3ds;
+		matr->twosided = True3ds;
 		PutMaterial3ds(db, matr);
 		ReleaseMaterial3ds(&matr);
 	}
@@ -438,7 +455,7 @@ void Export3DStudio()
 		memset(facemats, 0, sizeof(facemats));
 
 		PieceInfo* pInfo = pPiece->GetPieceInfo();
-		if (pInfo->m_nFlags & LC_PIECE_LONGDATA)
+		if (pInfo->m_nFlags & LC_PIECE_LONGDATA_INDICES)
 			continue; // 3DS can't handle this
 
 		// count number of faces used
@@ -788,3 +805,11 @@ void Export3DStudio()
 	CloseFile3ds(file);
 	ReleaseDatabase3ds(&db);
 }
+
+#else
+
+void Export3DStudio() 
+{
+}
+
+#endif
