@@ -1,5 +1,5 @@
 //{{NO_DEPENDENCIES}}
-// Microsoft Developer Studio generated include file.
+// Microsoft Visual C++ generated include file.
 // Used by LeoCAD.rc
 //
 #define IDAPPLY                         3
@@ -56,77 +56,49 @@
 #define IDD_SELECT_OBJECTS              152
 #define IDD_ARRAY                       153
 #define IDD_STEP                        154
-#define IDB_VIEWPORTS                   155
 #define IDB_PIECEBAR                    156
 #define IDD_IMAGE                       158
 #define IDD_HTML                        159
 #define IDD_PROGRESS                    161
 #define IDR_PARTFRAME                   162
-#define IDB_AUTOPAN                     164
-#define IDC_PAN_UP                      165
-#define IDC_PAN_LEFT                    166
-#define IDC_PAN_DOWN                    167
-#define IDC_PAN_RIGHT                   168
-#define IDC_PAN_ALL                     169
 #define IDD_GROUP                       170
-#define IDB_HELP                        172
-#define IDB_HOME                        173
-#define IDB_MAIL                        174
-#define IDB_INFO                        175
 #define IDS_COLOR01                     176
 #define IDS_COLOR02                     177
 #define IDB_PARTICONS                   177
 #define IDD_OPENDLG_TEMPLATE            177
 #define IDS_COLOR03                     178
-#define IDD_MODIFY                      178
 #define IDS_COLOR04                     179
 #define IDS_COLOR05                     180
 #define IDS_COLOR06                     181
 #define IDS_COLOR07                     182
 #define IDS_COLOR08                     183
 #define IDS_COLOR09                     184
-#define IDB_PIECE                       184
 #define IDS_COLOR10                     185
-#define IDB_CAMERA                      185
 #define IDS_COLOR11                     186
-#define IDB_LIGHT                       186
 #define IDS_COLOR12                     187
 #define IDS_COLOR13                     188
 #define IDS_COLOR14                     189
-#define IDB_ZOOMIN                      189
 #define IDS_COLOR15                     190
-#define IDB_ZOOMOUT                     190
 #define IDS_COLOR16                     191
-#define IDB_GROUP                       191
 #define IDS_COLOR17                     192
-#define IDB_UNGROUP                     192
 #define IDS_COLOR18                     193
 #define IDD_MINIFIG                     193
 #define IDR_FULLSCREEN                  193
 #define IDS_COLOR19                     194
 #define IDD_SAVEDLG_TEMPLATE            194
 #define IDS_COLOR20                     195
-#define IDB_FULLSCREEN                  195
 #define IDS_COLOR21                     196
 #define IDS_COLOR22                     197
-#define IDB_PHOTO                       197
 #define IDS_COLOR23                     198
 #define IDD_EXPORTPOV                   198
-#define IDB_DELETE                      198
 #define IDS_COLOR24                     199
-#define IDB_PREFERENCES                 199
 #define IDD_SAVEPICTUREDLG_TEMPLATE     199
 #define IDS_COLOR25                     200
 #define IDS_COLOR26                     201
-#define IDC_PAN_NE                      201
 #define IDS_COLOR27                     202
-#define IDC_PAN_NW                      202
 #define IDS_COLOR28                     203
-#define IDC_PAN_SE                      203
-#define IDC_PAN_SW                      204
 #define IDR_PIECEEDITOR                 205
 #define IDD_PIECEEDITOR                 208
-#define IDB_EDITOR_ICONS                209
 #define IDD_LIBRARY                     211
 #define IDR_LIBRARY                     213
 #define IDD_TERRAIN                     216
@@ -140,6 +112,7 @@
 #define IDD_CATEGORY                    237
 #define IDC_ROTX                        238
 #define IDC_ROTY                        239
+#define IDR_INVISIBLE                   240
 #define IDC_SELDLG_LIST                 1000
 #define IDC_SELDLG_ALL                  1001
 #define IDC_SELDLG_NONE                 1002
@@ -207,7 +180,6 @@
 #define IDC_PROP_PIECES_LIST            1072
 #define IDC_ABTDLG_INFO                 1073
 #define IDC_GENDLG_NUMBERS              1074
-#define IDC_MODDLG_HIDDEN               1074
 #define IDC_SAVEDLG_PREVIEW             1074
 #define IDC_GENDLG_PREVIEW              1075
 #define IDC_AIDDLG_SNAPX                1076
@@ -255,20 +227,14 @@
 #define IDC_DETDLG_ANTIALIAS            1094
 #define IDC_AIDDLG_ANGLE                1095
 #define IDC_GENDLG_SAVETIME             1095
-#define IDC_MODDLG_ROTX                 1095
 #define IDC_EDTDLG_CONNECTION           1095
 #define IDC_DETDLG_LINE                 1096
 #define IDC_PRNDLG_MARGIN_TOP           1096
 #define IDC_AIDDLG_GRIDSIZE             1096
-#define IDC_MODDLG_ROTY                 1096
 #define IDC_DETDLG_HIDDEN               1097
 #define IDC_PRNDLG_MARGIN_BOTTOM        1097
-#define IDC_MODDLG_ROTZ                 1097
 #define IDC_DETDLG_BACKGROUND           1098
 #define IDC_PRNDLG_MARGIN_RIGHT         1098
-#define IDC_MODDLG_POSX                 1098
-#define IDC_MODDLG_POSY                 1099
-#define IDC_MODDLG_POSZ                 1100
 #define IDC_OPENDLG_PREVIEW             1102
 #define IDC_OPENDLG_TEXT                1103
 #define IDC_SCNDLG_BGIMAGE_BROWSE       1104
@@ -301,35 +267,18 @@
 #define IDC_GENDLG_MOUSE                1132
 #define IDC_GENDLG_GAMMA                1133
 #define IDC_GENDLG_USER                 1133
-#define IDC_MODDLG_LIST                 1136
-#define IDC_MODDLG_COLOR                1137
-#define IDC_MODDLG_PIECE                1142
-#define IDC_MODDLG_ROTATION             1145
-#define IDC_MODDLG_FROM                 1146
 #define IDC_EDTDLG_DESCRIPTION          1146
-#define IDC_MODDLG_TO                   1147
 #define IDC_EDTDLG_NAME                 1147
-#define IDC_MODDLG_ROTATION2            1148
 #define IDC_IMGDLG_PAUSE                1148
-#define IDC_MODDLG_STEPFROM             1148
 #define IDC_POVDLG_LGEO                 1148
 #define IDC_POVDLG_POVRAY               1149
-#define IDC_MODDLG_FOV                  1149
-#define IDC_MODDLG_OK                   1150
 #define IDC_POVDLG_RENDER               1150
-#define IDC_MODDLG_UPY                  1150
-#define IDC_MODDLG_CLOSE                1151
 #define IDC_POVDLG_LGEOBROWSE           1151
-#define IDC_MODDLG_UPX                  1151
-#define IDC_MODDLG_APPLY                1152
 #define IDC_POVDLG_POVBROWSE            1152
 #define IDC_POVDLG_OUTPOV               1153
-#define IDC_MODDLG_UPZ                  1153
 #define IDC_IMGDLG_SINGLE               1154
 #define IDC_POVDLG_POVOUTBROWSE         1154
-#define IDC_MODDLG_NEAR                 1154
 #define IDC_IMGDLG_MULTIPLE             1155
-#define IDC_MODDLG_FAR                  1155
 #define IDC_IMGDLG_BMP                  1158
 #define IDC_IMGDLG_JPG                  1160
 #define IDC_IMGDLG_AVI                  1161
@@ -337,8 +286,6 @@
 #define IDC_IMGDLG_TO                   1163
 #define IDC_SAVEPICTURE_OPTIONS         1164
 #define IDC_IMGDLG_PNG                  1164
-#define IDC_MODDLG_STEPTO               1165
-#define IDC_MODDLG_FOVSTATIC            1166
 #define IDC_EDITORSTATIC                1167
 #define IDC_EDTDLG_LIST                 1168
 #define IDC_BUTTON2                     1170
@@ -401,14 +348,12 @@
 #define IDC_TREE                        1214
 #define IDC_TRANSDLG_OZ                 1214
 #define IDC_MF_LEGL                     1215
-#define IDC_MODDLG_PLANESSTATIC         1215
 #define IDC_MF_LEGR                     1216
 #define IDC_MF_SHOEL                    1217
 #define IDC_MF_SHOER                    1218
 #define IDC_PREVIEWSTATIC               1219
-#define IDC_MF_HATANGLE                 1220
-#define IDC_MF_HEADANGLE                1221
-#define IDC_MF_NECKANGLE                1222
+#define IDC_MF_HATANGLE                 1221
+#define IDC_MF_HEADANGLE                1222
 #define IDC_MF_ARMLANGLE                1223
 #define IDC_HTMLDLG_HTMLEXT             1223
 #define IDC_MF_ARMRANGLE                1224
@@ -425,10 +370,9 @@
 #define IDC_KEYDLG_CMDLIST              1230
 #define IDC_MF_SHOELANGLE               1231
 #define IDC_MF_SHOERANGLE               1232
-#define IDC_MF_HATSPIN                  1233
 #define IDC_KEYDLG_REMOVE               1233
-#define IDC_MF_HEADSPIN                 1234
-#define IDC_MF_NECKSPIN                 1235
+#define IDC_MF_HATSPIN                  1234
+#define IDC_MF_HEADSPIN                 1235
 #define IDC_MF_ARMLSPIN                 1236
 #define IDC_KEYDLG_RESET                1236
 #define IDC_MF_ARMRSPIN                 1237
@@ -483,11 +427,9 @@
 #define ID_VIEW_PREFERENCES             32810
 #define ID_ANIMATOR_PLAY                32814
 #define ID_ANIMATOR_STOP                32815
-#define ID_RENDER_BACKGROUND            32820
 #define ID_RENDER_BOX                   32821
 #define ID_PIECE_INSERT                 32822
 #define ID_PIECE_DELETE                 32823
-#define ID_PIECE_MODIFY                 32824
 #define ID_VIEW_STEP_FIRST              32825
 #define ID_VIEW_STEP_LAST               32826
 #define ID_PIECE_HIDESELECTED           32827
@@ -528,59 +470,10 @@
 #define ID_PRINT_RIGHTALIGN             32882
 #define ID_SNAP_ON                      32883
 #define ID_SNAP_ANGLE                   32884
-#define ID_MODDLG_PIECES                32884
-#define ID_MODDLG_CAMERAS               32885
-#define ID_MODDLG_LIGHTS                32886
 #define ID_FILE_PRINTCATALOG            32887
 #define ID_LIBDLG_FILE_PRINTCATALOG     32887
 #define ID_FILE_MERGEUPDATE             32888
 #define ID_LIBDLG_FILE_MERGEUPDATE      32888
-#define ID_VIEWPORT01                   32891
-#define ID_VIEWPORT02                   32892
-#define ID_VIEWPORT03                   32893
-#define ID_VIEWPORT04                   32894
-#define ID_VIEWPORT05                   32895
-#define ID_VIEWPORT06                   32896
-#define ID_VIEWPORT07                   32897
-#define ID_VIEWPORT08                   32898
-#define ID_VIEWPORT09                   32899
-#define ID_VIEWPORT10                   32900
-#define ID_VIEWPORT11                   32901
-#define ID_VIEWPORT12                   32902
-#define ID_VIEWPORT13                   32903
-#define ID_VIEWPORT14                   32904
-#define ID_PIECE_GROUP01                32911
-#define ID_PIECE_GROUP02                32912
-#define ID_PIECE_GROUP03                32913
-#define ID_PIECE_GROUP04                32914
-#define ID_PIECE_GROUP05                32915
-#define ID_PIECE_GROUP06                32916
-#define ID_PIECE_GROUP07                32917
-#define ID_PIECE_GROUP08                32918
-#define ID_PIECE_GROUP09                32919
-#define ID_PIECE_GROUP10                32920
-#define ID_PIECE_GROUP11                32921
-#define ID_PIECE_GROUP12                32922
-#define ID_PIECE_GROUP13                32923
-#define ID_PIECE_GROUP14                32924
-#define ID_PIECE_GROUP15                32925
-#define ID_PIECE_GROUP16                32926
-#define ID_PIECE_GROUP17                32927
-#define ID_PIECE_GROUP18                32928
-#define ID_PIECE_GROUP19                32929
-#define ID_PIECE_GROUP20                32930
-#define ID_PIECE_GROUP21                32931
-#define ID_PIECE_GROUP22                32932
-#define ID_PIECE_GROUP23                32933
-#define ID_PIECE_GROUP24                32934
-#define ID_PIECE_GROUP25                32935
-#define ID_PIECE_GROUP26                32936
-#define ID_PIECE_GROUP27                32937
-#define ID_PIECE_GROUP28                32938
-#define ID_PIECE_GROUP29                32939
-#define ID_PIECE_GROUP30                32940
-#define ID_PIECE_GROUP31                32941
-#define ID_PIECE_GROUP32                32942
 #define ID_CAMERA_FIRST                 32943
 #define ID_CAMERA_LAST                  33011
 #define ID_SNAP_SNAPX                   33012
@@ -635,19 +528,29 @@
 #define ID_SNAP_17                      33105
 #define ID_SNAP_18                      33106
 #define ID_SNAP_19                      33107
-#define ID_FILE_TERRAINEDITOR           33108
-#define ID_TERDLG_FILE_SAVEAS           33112
-#define ID_TERDLG_EDIT_RANDOM           33113
-#define ID_TERDLG_FILE_OPEN             33114
-#define ID_TERDLG_FILE_SAVE             33115
-#define ID_TERDLG_EDIT_PREFERENCES      33116
-#define ID_TERDLG_EDIT_SELECT           33119
-#define ID_TERDLG_EDIT_ZOOM             33120
-#define ID_TERDLG_EDIT_PAN              33121
-#define ID_TERDLG_EDIT_ROTATE           33122
-#define ID_TERDLG_EDIT_RESETCAMERA      33124
-#define ID_TERDLG_HELP                  33125
-#define ID_VIEW_CAMERAS_RESET           33126
+#define ID_SNAP_20                      33108
+#define ID_SNAP_21                      33109
+#define ID_SNAP_22                      33110
+#define ID_SNAP_23                      33111
+#define ID_SNAP_24                      33112
+#define ID_SNAP_25                      33113
+#define ID_SNAP_26                      33114
+#define ID_SNAP_27                      33115
+#define ID_SNAP_28                      33116
+#define ID_SNAP_29                      33117
+#define ID_FILE_TERRAINEDITOR           33118
+#define ID_TERDLG_FILE_SAVEAS           33119
+#define ID_TERDLG_EDIT_RANDOM           33120
+#define ID_TERDLG_FILE_OPEN             33121
+#define ID_TERDLG_FILE_SAVE             33122
+#define ID_TERDLG_EDIT_PREFERENCES      33123
+#define ID_TERDLG_EDIT_SELECT           33124
+#define ID_TERDLG_EDIT_ZOOM             33125
+#define ID_TERDLG_EDIT_PAN              33126
+#define ID_TERDLG_EDIT_ROTATE           33127
+#define ID_TERDLG_EDIT_RESETCAMERA      33128
+#define ID_TERDLG_HELP                  33129
+#define ID_VIEW_CAMERAS_RESET           33130
 #define ID_PREVIEW_ONEPAGE              33132
 #define ID_PREVIEW_TWOPAGES             33133
 #define ID_PREVIEW_PRINT                33134
@@ -667,7 +570,6 @@
 #define ID_LOCK_ON                      33149
 #define ID_PIECE_MIRROR                 33150
 #define ID_FILE_IMPORTPIECE             33152
-#define ID_VIEW_NEWVIEW                 33153
 #define ID_VIEW_STEP_DELETE             33154
 #define ID_LIBDLG_FILE_TEXTURES         33157
 #define ID_PIECEBAR_NEWCATEGORY         33159
@@ -680,18 +582,27 @@
 #define ID_LIBDLG_CATEGORY_RESET        33166
 #define ID_SNAP_XY                      33167
 #define ID_SNAP_Z                       33168
+#define ID_VIEW_SPLITVERTICALLY         33171
+#define ID_VIEW_SPLITHORIZONTALLY       33172
+#define ID_VIEW_DELETEVIEW              33173
+#define ID_VIEW_RESETVIEWS              33174
+#define ID_VIEW_TOOLBARS                33175
+#define ID_VIEW_SPLIT_HORIZONTALLY      33177
+#define ID_TOOLBARS_PROPERTIES          33178
+#define ID_FILE_IMPORTFOLDER            33179
 #define ID_VIEW_PIECES_BAR              59425
 #define ID_VIEW_TOOLS_BAR               59426
 #define ID_VIEW_ANIMATION_BAR           59427
-#define ID_VIEW_MODIFY_BAR              59428
+#define ID_VIEW_PROPERTIES_BAR          59428
+#define ID_VIEW_INVISIBLE_BAR           59429
 
 // Next default values for new objects
 // 
 #ifdef APSTUDIO_INVOKED
 #ifndef APSTUDIO_READONLY_SYMBOLS
 #define _APS_3D_CONTROLS                     1
-#define _APS_NEXT_RESOURCE_VALUE        240
-#define _APS_NEXT_COMMAND_VALUE         33169
+#define _APS_NEXT_RESOURCE_VALUE        242
+#define _APS_NEXT_COMMAND_VALUE         33180
 #define _APS_NEXT_CONTROL_VALUE         1247
 #define _APS_NEXT_SYMED_VALUE           121
 #endif
